@@ -99,6 +99,7 @@ protected :
     bool FileHeader_Begin();
     void FileHeader_Parse();
     void FileHeader_Parse_ADIF();
+    void FileHeader_Parse_ADTS();
 
     //Buffer - Global
     void Read_Buffer_Continue ();
@@ -174,7 +175,6 @@ protected :
     int16u  frameLength[128];
     int32u  MuxSlotLengthBytes[128];
     int32u  otherDataLenBits;
-    bool    otherDataPresent;
     bool    allStreamsSameTimeFraming;
     int8u   audioObjectType;
     int8u   extensionAudioObjectType;
@@ -269,6 +269,32 @@ protected :
     void ELDSpecificConfig                  ();
     void ld_sbr_header                      ();
 
+    //Elements - USAC
+    void UsacConfig                         ();
+    void UsacDecoderConfig                  (int8u coreSbrFrameLengthIndex);
+    void UsacSingleChannelElementConfig     (int8u coreSbrFrameLengthIndex);
+    void UsacChannelPairElementConfig       (int8u coreSbrFrameLengthIndex);
+    void UsacLfeElementConfig               ();
+    void UsacExtElementConfig               ();
+    void UsacCoreConfig                     ();
+    void SbrConfig                          ();
+    void SbrDlftHeader                      ();
+    void Mps212Config                       (int8u StereoConfigindex);
+    void uniDrcConfig                       ();
+    void uniDrcConfigExtension              ();
+    void downmixInstructions                (bool V1=false);
+    void drcCoefficientsBasic               ();
+    void drcCoefficientsUniDrc              (bool V1=false);
+    void drcInstructionsBasic               ();
+    void drcInstructionsUniDrc              (bool V1=false);
+    void channelLayout                      ();
+    void UsacConfigExtension                ();
+    void loudnessInfoSet                    (bool V1=false);
+    void loudnessInfo                       (bool FromAlbum, bool V1=false);
+    void loudnessInfoSetExtension           ();
+    void streamId                           ();
+    void escapedValue                       (int32u &Value, int8u nBits1, int8u nBits2, int8u nBits3, const char* Name);
+
     //Helpers
     void hcod                               (int8u sect_cb, const char* Name);
     void hcod_sf                            (const char* Name);
@@ -366,8 +392,38 @@ protected :
 
     std::map<std::string, Ztring>   Infos_General;
     std::map<std::string, Ztring>   Infos;
+    std::map<std::string, Ztring>   Infos_AudioSpecificConfig;
     bool                            CanFill;
 
+    //***********************************************************************
+    // Temp USAC
+    //***********************************************************************
+
+    struct drc_info
+    {
+        string                      drcSetEffectTotal;
+    };
+    struct loudness_info
+    {
+        struct measurements
+        {
+            Ztring                  Values[16];
+        };
+        Ztring                      SamplePeakLevel;
+        Ztring                      TruePeakLevel;
+        measurements                Measurements;
+    };
+    std::map<Ztring, drc_info>      drcInstructionsUniDrc_Data; // By id
+    std::map<Ztring, loudness_info> loudnessInfo_Data[2]; // By non-album/album then by id
+    int8u                           baseChannelCount;
+    int8u                           targetChannelCount;
+    struct gain_set
+    {
+        int8u                       bandCount;
+    };
+    std::vector<gain_set>           gainSets;
+    bool                            loudnessInfoSet_Present;
+
 private :
     void FillInfosHEAACv2(const Ztring& Format_Settings);
 };
