@@ -85,18 +85,15 @@ public :
                 Buffer_Size-=Buffer_Offset;
                 Buffer_Offset=0;
             }
-
         };
         vector<channel*>    Channels;
         channel             MergedChannel;
-        size_t              Channel_Current;
         std::vector<File__Analyze*> Parsers;
         size_t              Instances;
         size_t              Instances_Max;
 
         common()
         {
-            Channel_Current=0;
             Instances=0;
             Instances_Max=0;
         }
