@@ -301,7 +301,7 @@ File_Mpega::File_Mpega()
     MustSynchronize=true;
     Buffer_TotalBytes_FirstSynched_Max=64*1024;
     PTS_DTS_Needed=true;
-    IsRawStream=true;
+    StreamSource=IsStream;
     Frame_Count_NotParsedIncluded=0;
 
     //In
@@ -1034,7 +1034,7 @@ void File_Mpega::Data_Parse()
     }
 
     //error_check
-    if (protection_bit)
+    if (!protection_bit)
     {
         Element_Begin1("error_check");
         Skip_B2(                                                "crc_check");
@@ -1297,9 +1297,6 @@ bool File_Mpega::Header_Xing()
             if (Lame || Lib=="LAME" || Lib=="GOGO" || Lib=="L3.9")
                 Header_Encoders_Lame();
 
-            if (CC4(Xing_Header)==CC4("Info"))
-                VBR_Frames=0; //This is not a VBR file
-
             //Clearing Error detection
             sampling_frequency_Count.clear();
             mode_Count.clear();
