@@ -41,6 +41,7 @@
     #include "MediaInfo/MediaInfo_Internal.h"
 #endif // MEDIAINFO_SEEK
 #include "MediaInfo/File_Unknown.h"
+#include "MediaInfo/MediaInfo_Config_MediaInfo.h"
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -153,12 +154,6 @@ File_SmpteSt0337::File_SmpteSt0337()
     GuardBand_After=0;
     NullPadding_Size=0;
 
-    #if MEDIAINFO_EVENTS
-        pid=(int16u)-1;
-        stream_id=(int8u)-1;
-        IgnoreGuardBandTest=false;
-    #endif MEDIAINFO_EVENTS
-
     // Parser
     Parser=NULL;
 
@@ -196,7 +191,9 @@ void File_SmpteSt0337::Streams_Fill()
         if (OverallBitRate)
         {
             OverallBitRate*=Element_Size; OverallBitRate/=Element_Size-Stream_Bits*4/8;
-            Fill(Stream_General, 0, General_OverallBitRate, Ztring::ToZtring(OverallBitRate)+__T(" / ")+Parser->Retrieve(Stream_General, 0, General_OverallBitRate));
+            OverallBitRate*=Container_Bits;
+            OverallBitRate/=Stream_Bits;
+            Fill(Stream_General, 0, General_OverallBitRate, OverallBitRate);
         }
         if (Parser->Count_Get(Stream_Audio))
             FrameRate=Retrieve(Stream_Audio, 0, Audio_FrameRate).To_float64();
@@ -221,7 +218,7 @@ void File_SmpteSt0337::Streams_Fill()
 
     if (FrameRate && FrameSizes.size()==1)
     {
-        Fill(Stream_General, 0, General_OverallBitRate, FrameSizes.begin()->first*Container_Bits*FrameRate, 0);
+        Fill(Stream_General, 0, General_OverallBitRate, FrameSizes.begin()->first*8*FrameRate, 0, true);
     }
 
     for (size_t Pos=0; Pos<Count_Get(StreamKind_Last); Pos++)
@@ -248,10 +245,30 @@ void File_SmpteSt0337::Streams_Fill()
             Fill(StreamKind_Last, Pos, "MuxingMode", "SMPTE ST 337");
         if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitRate_Mode))!=__T("CBR"))
             Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitRate_Mode), "CBR");
-        if (File_Size!=(int64u)-1 && FrameSizes.size()==1)
-            Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_FrameCount), File_Size/FrameSizes.begin()->first);
-        if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_Duration)).empty())
-            Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_Duration), Retrieve(Stream_General, 0, General_Duration));
+    }
+}
+
+//---------------------------------------------------------------------------
+void File_SmpteSt0337::Streams_Finish()
+{
+    if (Parser && Parser->Status[IsAccepted])
+    {
+        Finish(Parser);
+        for (size_t Pos=0; Pos<Count_Get(Stream_Audio); Pos++)
+        {
+            if (!Parser->Retrieve(Stream_Audio, Pos, Audio_Duration).empty())
+                Fill(Stream_Audio, Pos, Audio_Duration, Parser->Retrieve(Stream_Audio, Pos, Audio_Duration), true);
+            if (!Parser->Retrieve(Stream_Audio, Pos, Audio_FrameCount).empty())
+                Fill(Stream_Audio, Pos, Audio_FrameCount, Parser->Retrieve(Stream_Audio, Pos, Audio_FrameCount), true);
+
+            if (!IsSub)
+            {
+                if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(Stream_Audio, Generic_FrameCount)).empty() && File_Size!=(int64u)-1 && FrameSizes.size()==1)
+                    Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_FrameCount), File_Size/FrameSizes.begin()->first);
+                if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_Duration)).empty())
+                    Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_Duration), Retrieve(Stream_General, 0, General_Duration));
+            }
+        }
     }
 }
 
@@ -268,6 +285,9 @@ void File_SmpteSt0337::Read_Buffer_Unsynched()
         Frame_Count_NotParsedIncluded=float64_int64s(File_GoTo/FrameRate);
         FrameInfo.DTS=Frame_Count_NotParsedIncluded*1000000000/48000;
     }
+
+    if (Parser)
+        Parser->Open_Buffer_Unsynch();
 }
 #endif // MEDIAINFO_SEEK
 
@@ -823,8 +843,11 @@ void File_SmpteSt0337::Synched_Init()
 {
     if (Frame_Count_NotParsedIncluded==(int64u)-1)
         Frame_Count_NotParsedIncluded=0;
-    if (FrameInfo.DTS==(int64u)-1)
-        FrameInfo.DTS=0;
+    if (!IsSub)
+    {
+        FrameInfo.DTS=0; //No DTS in container
+        FrameInfo.PTS=0; //No PTS in container
+    }
 }
 
 //***************************************************************************
@@ -1135,6 +1158,7 @@ void File_SmpteSt0337::Data_Parse()
 
     // Parsing
     int32u  length_code;
+    int8u data_type_New;
     Element_Begin1("Header");
         BS_Begin();
         Skip_S3(Stream_Bits,                                    "Pa");
@@ -1144,7 +1168,7 @@ void File_SmpteSt0337::Data_Parse()
             Skip_S1( 5,                                         "data_type_dependent");
             Skip_SB(                                            "error_flag");
             Info_S1( 2, data_mode,                              "data_mode"); Param_Info2(16+4*data_mode, " bits");
-            Get_S1 ( 5, data_type,                              "data_type"); Param_Info1(Smpte_St0337_data_type[data_type]);
+            Get_S1 ( 5, data_type_New,                          "data_type"); Param_Info1(Smpte_St0337_data_type[data_type_New]);
             if (Stream_Bits>16)
                 Skip_S1( 4,                                     "reserved");
             if (Stream_Bits>20)
@@ -1154,6 +1178,11 @@ void File_SmpteSt0337::Data_Parse()
         BS_End();
     Element_End0();
 
+    if (data_type_New!=data_type)
+    {
+        delete Parser; Parser=NULL;
+        data_type=data_type_New;
+    }
     if (Parser==NULL)
     {
         switch(data_type)
@@ -1212,7 +1241,17 @@ void File_SmpteSt0337::Data_Parse()
                         #endif //defined(MEDIAINFO_AAC_YES)
                         break;
             case 28 :   // Dolby E
+                        #if defined(MEDIAINFO_DOLBYE_YES)
                         Parser=new File_DolbyE();
+                        #else
+                        {
+                            //Filling
+                            File__Analyze* Parser=new File_Unknown();
+                            Open_Buffer_Init(Parser);
+                            Parser->Stream_Prepare(Stream_Audio);
+                            Parser->Fill(Stream_Audio, 0, Audio_Format, "DDE");
+                        }
+                        #endif
                         break;
             default : ;
         }
@@ -1289,6 +1328,7 @@ void File_SmpteSt0337::Data_Parse()
 
     if (Parser && !Parser->Status[IsFinished])
     {
+        #if defined(MEDIAINFO_DOLBYE_YES)
         switch(data_type)
         {
             case 28 :
@@ -1298,6 +1338,7 @@ void File_SmpteSt0337::Data_Parse()
                         break;
             default : ;
         }
+        #endif
 
         Parser->FrameInfo=FrameInfo;
         Open_Buffer_Continue(Parser, Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset));
@@ -1305,12 +1346,20 @@ void File_SmpteSt0337::Data_Parse()
         #if MEDIAINFO_DEMUX
             FrameInfo.DUR=Parser->FrameInfo.DUR;
             if (FrameInfo.DUR!=(int64u)-1)
-                FrameInfo.DTS+=FrameInfo.DUR;
+            {
+                if (FrameInfo.DTS!=(int64u)-1)
+                    FrameInfo.DTS+=FrameInfo.DUR;
+                if (FrameInfo.PTS!=(int64u)-1)
+                    FrameInfo.PTS+=FrameInfo.DUR;
+            }
             else
+            {
                 FrameInfo.DTS=(int64u)-1;
-            FrameInfo.PTS=FrameInfo.DTS;
+                FrameInfo.PTS=(int64u)-1;
+            }
         #endif // MEDIAINFO_DEMUX
 
+        #if defined(MEDIAINFO_DOLBYE_YES)
         switch (data_type)
         {
             case 28 :
@@ -1320,25 +1369,13 @@ void File_SmpteSt0337::Data_Parse()
                         break;
             default : ;
         }
+        #endif
     }
     else
     {
         Skip_XX(Element_Size-Element_Offset,                    "Data");
     }
 
-    FILLING_BEGIN();
-        FrameSizes[IsSub?Buffer_Size:((GuardBand_Before+Element_Size)*Container_Bits/Stream_Bits)]++;
-
-        Frame_Count++;
-        if (Frame_Count_NotParsedIncluded!=(int64u)-1)
-            Frame_Count_NotParsedIncluded++;
-
-        if (Parser==NULL || (Frame_Count>=2 && Parser->Status[IsFilled]))
-            Fill("SMPTE ST 337");
-        if (Parser==NULL || (Frame_Count>=2 && Parser->Status[IsFinished]))
-            Finish("SMPTE ST 337");
-    FILLING_END();
-
     if (Save_Buffer)
     {
         delete[] Buffer;
@@ -1350,6 +1387,26 @@ void File_SmpteSt0337::Data_Parse()
 
     // Guard band
     GuardBand_Before=0;
+
+    FILLING_BEGIN();
+        FrameSizes[IsSub?Buffer_Size:((GuardBand_Before+Element_Size)*Container_Bits/Stream_Bits)]++;
+
+        Frame_Count++;
+        if (Frame_Count_NotParsedIncluded!=(int64u)-1)
+            Frame_Count_NotParsedIncluded++;
+
+        if (Parser==NULL || (Frame_Count>=2 && Parser->Status[IsFilled]))
+        {
+            Fill("SMPTE ST 337");
+            if (!IsSub && Config->ParseSpeed<1.0)
+            {
+                Open_Buffer_Unsynch();
+                Finish();
+            }
+        }
+        if (Parser==NULL || (Frame_Count>=2 && Parser->Status[IsFinished]))
+            Finish("SMPTE ST 337");
+    FILLING_END();
 }
 
 //***************************************************************************
