@@ -98,7 +98,7 @@ void File__Analyze::BS_Begin()
     else
         BS_Size=0;
 
-    BS->Attach(Buffer+Buffer_Offset+(size_t)Element_Offset, BS_Size);
+    BS->Attach(Buffer+Buffer_Offset+(size_t)(BS_Size?Element_Offset:0), BS_Size);
     #if MEDIAINFO_TRACE
         BS_Size<<=3; //In bits
     #endif
@@ -458,6 +458,28 @@ void File__Analyze::Skip_B16(const char* Name)
     Element_Offset+=16;
 }
 
+//---------------------------------------------------------------------------
+void File__Analyze::Skip_Hexa(int8u Bytes, const char* Name)
+{
+    INTEGRITY_SIZE_ATLEAST(Bytes);
+    if (Trace_Activated)
+    {
+        string ValueS;
+        ValueS.resize(Bytes*2);
+        const int8u* Buffer_Temp=Buffer+Buffer_Offset+(size_t)Element_Offset;
+        for (int8u i=0; i<Bytes; i++)
+        {
+            int8u Value=Buffer_Temp[i];
+            int8u Value0=Value>>4;
+            int8u Value1=Value&0xF;
+            ValueS[i*2  ]=Value0+(Value0>9?('A'-10):('0'));
+            ValueS[i*2+1]=Value1+(Value1>9?('A'-10):('0'));
+        }
+        Param(Name, ValueS);
+    }
+    Element_Offset+=Bytes;
+}
+
 //---------------------------------------------------------------------------
 void File__Analyze::Skip_BF4(const char* Name)
 {
@@ -1543,7 +1565,7 @@ void File__Analyze::Get_C1(int8u &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(1);
     Info=CC1(Buffer+Buffer_Offset+(size_t)Element_Offset);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 1);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 1);
     Element_Offset+=1;
 }
 
@@ -1552,7 +1574,7 @@ void File__Analyze::Get_C2(int16u &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(2);
     Info=CC2(Buffer+Buffer_Offset+(size_t)Element_Offset);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 2);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 2);
     Element_Offset+=2;
 }
 
@@ -1561,7 +1583,7 @@ void File__Analyze::Get_C3(int32u &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(3);
     Info=CC3(Buffer+Buffer_Offset+(size_t)Element_Offset);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 3);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 3);
     Element_Offset+=3;
 }
 
@@ -1570,7 +1592,7 @@ void File__Analyze::Get_C4(int32u &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(4);
     Info=CC4(Buffer+Buffer_Offset+(size_t)Element_Offset);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 4, false);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 4);
     Element_Offset+=4;
 }
 
@@ -1579,7 +1601,7 @@ void File__Analyze::Get_C5(int64u &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(5);
     Info=CC5(Buffer+Buffer_Offset+(size_t)Element_Offset);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 5);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 5);
     Element_Offset+=5;
 }
 
@@ -1588,7 +1610,7 @@ void File__Analyze::Get_C6(int64u &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(6);
     Info=CC6(Buffer+Buffer_Offset+(size_t)Element_Offset);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 6);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 6);
     Element_Offset+=6;
 }
 
@@ -1597,7 +1619,7 @@ void File__Analyze::Get_C7(int64u &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(7);
     Info=CC7(Buffer+Buffer_Offset+(size_t)Element_Offset);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 7);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 7);
     Element_Offset+=7;
 }
 
@@ -1606,7 +1628,7 @@ void File__Analyze::Get_C8(int64u &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_INT(8);
     Info=CC8(Buffer+Buffer_Offset+(size_t)Element_Offset);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 8);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 8);
     Element_Offset+=8;
 }
 
@@ -1614,7 +1636,7 @@ void File__Analyze::Get_C8(int64u &Info, const char* Name)
 void File__Analyze::Skip_C1(const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(1);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 1);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 1);
     Element_Offset+=1;
 }
 
@@ -1622,7 +1644,7 @@ void File__Analyze::Skip_C1(const char* Name)
 void File__Analyze::Skip_C2(const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(2);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 2);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 2);
     Element_Offset+=2;
 }
 
@@ -1630,7 +1652,7 @@ void File__Analyze::Skip_C2(const char* Name)
 void File__Analyze::Skip_C3(const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(3);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 3);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 3);
     Element_Offset+=3;
 }
 
@@ -1638,7 +1660,7 @@ void File__Analyze::Skip_C3(const char* Name)
 void File__Analyze::Skip_C4(const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(4);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 4);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 4);
     Element_Offset+=4;
 }
 
@@ -1646,7 +1668,7 @@ void File__Analyze::Skip_C4(const char* Name)
 void File__Analyze::Skip_C5(const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(5);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 5);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 5);
     Element_Offset+=5;
 }
 
@@ -1654,7 +1676,7 @@ void File__Analyze::Skip_C5(const char* Name)
 void File__Analyze::Skip_C6(const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(6);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 6);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 6);
     Element_Offset+=6;
 }
 
@@ -1662,7 +1684,7 @@ void File__Analyze::Skip_C6(const char* Name)
 void File__Analyze::Skip_C7(const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(7);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 7);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 7);
     Element_Offset+=7;
 }
 
@@ -1670,7 +1692,7 @@ void File__Analyze::Skip_C7(const char* Name)
 void File__Analyze::Skip_C8(const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(8);
-    if (Trace_Activated) Param(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 8);
+    if (Trace_Activated) Param_CC(Name, Buffer+Buffer_Offset+(size_t)Element_Offset, 8);
     Element_Offset+=8;
 }
 
@@ -1682,7 +1704,11 @@ void File__Analyze::Skip_C8(const char* Name)
 void File__Analyze::Get_Local(int64u Bytes, Ztring &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_STRING(Bytes);
+    #ifdef WINDOWS
     Info.From_Local((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes);
+    #else //WINDOWS
+    Info.From_ISO_8859_1((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes); //Trying with the most commonly used charset before UTF8
+    #endif //WINDOWS
     if (Trace_Activated && Bytes) Param(Name, Info);
     Element_Offset+=Bytes;
 }
@@ -1842,12 +1868,38 @@ void File__Analyze::Get_ISO_8859_5(int64u Bytes, Ztring &Info, const char* Name)
     Element_Offset+=Bytes;
 }
 
+//---------------------------------------------------------------------------
+extern const int16u Ztring_MacRoman[128];
+void File__Analyze::Get_MacRoman(int64u Bytes, Ztring& Info, const char* Name)
+{
+    INTEGRITY_SIZE_ATLEAST_STRING(Bytes);
+
+    // Use From_MacRoman() after new ZenLib release
+    const int8u* Input=Buffer+Buffer_Offset+(size_t)Element_Offset;
+
+    wchar_t* Temp=new wchar_t[Bytes+1];
+
+    for (size_t Pos=0; Pos<=Bytes; Pos++)
+    {
+        if (Input[Pos]>=0x80)
+            Temp[Pos]=(wchar_t)Ztring_MacRoman[Input[Pos]-0x80];
+        else
+            Temp[Pos]=(wchar_t)Input[Pos];
+    }
+
+    Info.From_Unicode(Temp);
+    delete[] Temp;
+
+    if (Trace_Activated && Bytes) Param(Name, Info);
+    Element_Offset+=Bytes;
+}
+
 //---------------------------------------------------------------------------
 void File__Analyze::Get_String(int64u Bytes, std::string &Info, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST_STRING(Bytes);
     Info.assign((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes);
-    if (Trace_Activated && Bytes) Param(Name, Info);
+    if (Trace_Activated && Bytes) Param(Name, Ztring().From_ISO_8859_1((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes)); //Trying with the most commonly used charset
     Element_Offset+=Bytes;
 }
 
@@ -1855,7 +1907,11 @@ void File__Analyze::Get_String(int64u Bytes, std::string &Info, const char* Name
 void File__Analyze::Peek_Local(int64u Bytes, Ztring &Info)
 {
     INTEGRITY_SIZE_ATLEAST_STRING(Bytes);
+    #ifdef WINDOWS
     Info.From_Local((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes);
+    #else //WINDOWS
+    Info.From_ISO_8859_1((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes); //Trying with the most commonly used charset before UTF8
+    #endif //WINDOWS
 }
 
 //---------------------------------------------------------------------------
@@ -1905,7 +1961,11 @@ void File__Analyze::Get_UTF16L(int64u Bytes, Ztring &Info, const char* Name)
 void File__Analyze::Skip_Local(int64u Bytes, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(Bytes);
+    #ifdef WINDOWS
     if (Trace_Activated && Bytes) Param(Name, Ztring().From_Local((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes));
+    #else //WINDOWS
+    if (Trace_Activated && Bytes) Param(Name, Ztring().From_ISO_8859_1((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes)); //Trying with the most commonly used charset before UTF8
+    #endif //WINDOWS
     Element_Offset+=Bytes;
 }
 
@@ -1926,7 +1986,7 @@ void File__Analyze::Skip_ISO_6937_2(int64u Bytes, const char* Name)
 void File__Analyze::Skip_String(int64u Bytes, const char* Name)
 {
     INTEGRITY_SIZE_ATLEAST(Bytes);
-    if (Trace_Activated && Bytes) Param(Name, Ztring().From_Local((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes));
+    if (Trace_Activated && Bytes) Param(Name, Ztring().From_ISO_8859_1((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes)); //Trying with the most commonly used charset
     Element_Offset+=Bytes;
 }
 
@@ -1964,7 +2024,11 @@ void File__Analyze::Skip_PA(const char* Name)
     INTEGRITY_SIZE_ATLEAST(1);
     int8u Size=Buffer[Buffer_Offset+(size_t)Element_Offset];
     INTEGRITY_SIZE_ATLEAST(1+Size);
+    #ifdef WINDOWS
     if (Trace_Activated && Size) Param(Name, Ztring().From_Local((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset+1), (size_t)Size));
+    #else //WINDOWS
+    if (Trace_Activated && Size) Param(Name, Ztring().From_ISO_8859_1((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset+1), (size_t)Size)); //Trying with the most commonly used charset before UTF8
+    #endif //WINDOWS
     Element_Offset+=1+Size;
 }
 
