@@ -660,7 +660,7 @@ void File__Analyze::Peek_D8(int64u &Info)
 void File__Analyze::Get_GUID(int128u &Info)
 {
     INTEGRITY_SIZE_ATLEAST_INT(16);
-    Info.hi=LittleEndian2int64u(Buffer+Buffer_Offset+(size_t)Element_Offset);
+    Info.hi=BigEndian2int64u   (Buffer+Buffer_Offset+(size_t)Element_Offset);
     Info.lo=BigEndian2int64u   (Buffer+Buffer_Offset+(size_t)Element_Offset+8);
     Element_Offset+=16;
 }
@@ -938,9 +938,9 @@ void File__Analyze::Get_SE(int32s &Info)
     int8u LeadingZeroBits=0;
     while(BS->Remain()>0 && !BS->GetB())
         LeadingZeroBits++;
-    INTEGRITY(LeadingZeroBits<=32)
+    INTEGRITY_INT(LeadingZeroBits<=32)
     double InfoD=pow((float)2, (float)LeadingZeroBits)-1+BS->Get4(LeadingZeroBits);
-    INTEGRITY(InfoD<int32u(-1))
+    INTEGRITY_INT(InfoD<int32u(-1))
     Info=(int32s)(pow((double)-1, InfoD+1)*(int32u)ceil(InfoD/2));
 }
 
@@ -951,7 +951,7 @@ void File__Analyze::Get_UE(int32u &Info)
     int8u LeadingZeroBits=0;
     while(BS->Remain()>0 && !BS->GetB())
         LeadingZeroBits++;
-    INTEGRITY(LeadingZeroBits<=32)
+    INTEGRITY_INT(LeadingZeroBits<=32)
     double InfoD=pow((float)2, (float)LeadingZeroBits);
     Info=(int32u)InfoD-1+BS->Get4(LeadingZeroBits);
 }
@@ -1066,30 +1066,7 @@ void File__Analyze::Get_VL_(const vlc Vlc[], size_t &Info)
 void File__Analyze::Skip_VL_(const vlc Vlc[])
 {
     size_t Info=0;
-    int32u Value=0;
-
-    for(;;)
-    {
-        switch (Vlc[Info].bit_increment)
-        {
-            case 255 :
-                        Trusted_IsNot();
-                        return;
-            default  : ;
-                        Value<<=Vlc[Info].bit_increment;
-                        Value|=BS->Get1(Vlc[Info].bit_increment);
-                        break;
-            case   1 :
-                        Value<<=1;
-                        if (BS->GetB())
-                            Value++;
-            case   0 :  ;
-        }
-
-        if (Value==Vlc[Info].value)
-            return;
-        Info++;
-    }
+    Get_VL_(Vlc, Info);
 }
 
 //---------------------------------------------------------------------------
@@ -1238,7 +1215,11 @@ void File__Analyze::Get_C8(int64u &Info)
 void File__Analyze::Get_Local(int64u Bytes, Ztring &Info)
 {
     INTEGRITY_SIZE_ATLEAST_STRING(Bytes);
+    #ifdef WINDOWS
     Info.From_Local((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes);
+    #else //WINDOWS
+    Info.From_ISO_8859_1((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes); //Trying with the most commonly used charset before UTF8
+    #endif //WINDOWS
     Element_Offset+=Bytes;
 }
 
@@ -1393,6 +1374,31 @@ void File__Analyze::Get_ISO_8859_5(int64u Bytes, Ztring &Info)
     Element_Offset+=Bytes;
 }
 
+//---------------------------------------------------------------------------
+extern const int16u Ztring_MacRoman[128];
+void File__Analyze::Get_MacRoman(int64u Bytes, Ztring &Info)
+{
+    INTEGRITY_SIZE_ATLEAST_STRING(Bytes);
+
+    // Use From_MacRoman() after new ZenLib release
+    const int8u* Input =Buffer+Buffer_Offset+(size_t)Element_Offset;
+
+    wchar_t* Temp=new wchar_t[Bytes+1];
+
+    for (size_t Pos=0; Pos<=Bytes; Pos++)
+    {
+        if (Input[Pos]>=0x80)
+            Temp[Pos]=(wchar_t)Ztring_MacRoman[Input[Pos]-0x80];
+        else
+            Temp[Pos]=(wchar_t)Input[Pos];
+    }
+
+    Info.From_Unicode(Temp);
+    delete[] Temp;
+
+    Element_Offset+=Bytes;
+}
+
 //---------------------------------------------------------------------------
 void File__Analyze::Get_String(int64u Bytes, std::string &Info)
 {
@@ -1405,7 +1411,11 @@ void File__Analyze::Get_String(int64u Bytes, std::string &Info)
 void File__Analyze::Peek_Local(int64u Bytes, Ztring &Info)
 {
     INTEGRITY_SIZE_ATLEAST_STRING(Bytes);
+    #ifdef WINDOWS
     Info.From_Local((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes);
+    #else //WINDOWS
+    Info.From_ISO_8859_1((const char*)(Buffer+Buffer_Offset+(size_t)Element_Offset), (size_t)Bytes); //Trying with the most commonly used charset before UTF8
+    #endif //WINDOWS
 }
 
 //---------------------------------------------------------------------------
