@@ -24,6 +24,7 @@
 #include "MediaInfo/HashWrapper.h" //For MEDIAINFO_HASH
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Config.h"
+    #include "MediaInfo/MediaInfo_Config_PerPackage.h"
     #include "MediaInfo/MediaInfo_Events.h"
     #include "ZenLib/File.h"
 #endif //MEDIAINFO_EVENTS
@@ -31,6 +32,7 @@
 #include "ZenLib/Translation.h"
 #include "ZenLib/InfoMap.h"
 using namespace ZenLib;
+using std::string;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -38,7 +40,6 @@ namespace MediaInfoLib
 
 #if MEDIAINFO_EVENTS
     class File__Analyze;
-    class MediaInfo_Config_PerPackage;
 #endif //MEDIAINFO_EVENTS
 
 #if MEDIAINFO_AES
@@ -75,6 +76,8 @@ public :
     MediaInfo_Config_MediaInfo();
     ~MediaInfo_Config_MediaInfo();
 
+    bool          RequestTerminate;
+
     //General
     Ztring Option (const String &Option, const String &Value=Ztring());
 
@@ -84,6 +87,9 @@ public :
     void          File_IsSub_Set (bool NewValue);
     bool          File_IsSub_Get ();
 
+    void          File_ParseSpeed_Set(float32 NewValue, bool FromGlobal=false);
+    float32       File_ParseSpeed_Get();
+
     void          File_IsDetectingDuration_Set (bool NewValue);
     bool          File_IsDetectingDuration_Get ();
 
@@ -93,6 +99,9 @@ public :
     void          File_TestContinuousFileNames_Set (bool NewValue);
     bool          File_TestContinuousFileNames_Get ();
 
+    void          File_TestDirectory_Set (bool NewValue);
+    bool          File_TestDirectory_Get ();
+
     void          File_KeepInfo_Set (bool NewValue);
     bool          File_KeepInfo_Get ();
 
@@ -143,7 +152,11 @@ public :
         bool          File_RiskyBitRateEstimation_Get ();
         void          File_MergeBitRateInfo_Set (bool NewValue);
         bool          File_MergeBitRateInfo_Get ();
-    #endif //MEDIAINFO_ADVANCED
+        void          File_HighestFormat_Set (bool NewValue);
+        bool          File_HighestFormat_Get ();
+        void          File_ChannelLayout_Set(bool NewValue);
+        bool          File_ChannelLayout_Get();
+#endif //MEDIAINFO_ADVANCED
 
     #if MEDIAINFO_DEMUX
         #if MEDIAINFO_ADVANCED
@@ -182,6 +195,8 @@ public :
 
     void          File_ForceParser_Set (const Ztring &NewValue);
     Ztring        File_ForceParser_Get ();
+    void          File_ForceParser_Config_Set (const Ztring &NewValue);
+    Ztring        File_ForceParser_Config_Get ();
 
     void          File_Buffer_Size_Hint_Pointer_Set (size_t* NewValue);
     size_t*       File_Buffer_Size_Hint_Pointer_Get ();
@@ -283,6 +298,8 @@ public :
     int64u        Demux_FirstFrameNumber_Get ();
     void          Demux_InitData_Set (int8u NewValue);
     int8u         Demux_InitData_Get ();
+    void          Demux_SplitAudioBlocks_Set(bool NewValue);
+    bool          Demux_SplitAudioBlocks_Get();
     std::map<Ztring, File> Demux_Files;
     #endif //MEDIAINFO_DEMUX
 
@@ -332,7 +349,8 @@ public :
     #endif //MEDIAINFO_MACROBLOCKS
     void          File_GrowingFile_Delay_Set(float64 Value);
     float64       File_GrowingFile_Delay_Get();
-    void          File_GrowingFile_Force_Set(float64 Value);
+    void          File_GrowingFile_Force_Set(bool Value);
+    bool          File_GrowingFile_Force_Get();
     #if defined(MEDIAINFO_LIBCURL_YES)
     void          File_Curl_Set (const Ztring &NewValue);
     void          File_Curl_Set (const Ztring &Field, const Ztring &NewValue);
@@ -385,6 +403,8 @@ public :
     float64       File_EditRate;
     int64u        File_Size;
     float32       ParseSpeed;
+    bool          ParseSpeed_FromFile;
+    bool          IsFinishing;
     #if MEDIAINFO_EVENTS
     MediaInfo_Config_PerPackage* Config_PerPackage;
     bool          Events_TimestampShift_Disabled;
@@ -410,6 +430,7 @@ private :
     bool                    FileIsDetectingDuration;
     bool                    FileIsReferenced;
     bool                    FileTestContinuousFileNames;
+    bool                    FileTestDirectory;
     bool                    FileKeepInfo;
     bool                    FileStopAfterFilled;
     bool                    FileStopSubStreamAfterFilled;
@@ -425,6 +446,8 @@ private :
         bool                File_Source_List;
         bool                File_RiskyBitRateEstimation;
         bool                File_MergeBitRateInfo;
+        bool                File_HighestFormat;
+        bool                File_ChannelLayout;
         #if MEDIAINFO_DEMUX
             bool                File_Demux_Unpacketize_StreamLayoutChange_Skip;
         #endif //MEDIAINFO_DEMUX
@@ -444,6 +467,7 @@ private :
     Ztring                  File_Partial_Begin;
     Ztring                  File_Partial_End;
     Ztring                  File_ForceParser;
+    Ztring                  File_ForceParser_Config;
     size_t*                 File_Buffer_Size_Hint_Pointer;
     size_t                  File_Buffer_Read_Size;
 
@@ -513,6 +537,7 @@ private :
     bool                    Demux_Avc_Transcode_Iso14496_15_to_Iso14496_10;
     bool                    Demux_Hevc_Transcode_Iso14496_15_to_AnnexB;
     bool                    Demux_Unpacketize;
+    bool                    Demux_SplitAudioBlocks;
     float64                 Demux_Rate;
     int64u                  Demux_FirstDts;
     int64u                  Demux_FirstFrameNumber;
@@ -549,6 +574,7 @@ private :
     bool                    File_Macroblocks_Parse;
     #endif //MEDIAINFO_MACROBLOCKS
     float64                 File_GrowingFile_Delay;
+    bool                    File_GrowingFile_Force;
     #if defined(MEDIAINFO_LIBMMS_YES)
     bool                    File_Mmsh_Describe_Only;
     #endif //defined(MEDIAINFO_LIBMMS_YES)
