@@ -323,6 +323,33 @@ struct MediaInfo_Event_Global_BytesRead_0
     const MediaInfo_int8u*  Content;
 };
 
+/*-------------------------------------------------------------------------*/
+/* Decoded                                                                 */
+#define MediaInfo_Event_Global_Decoded 0xAF03
+
+struct MediaInfo_Event_Global_Decoded_0
+{
+    MEDIAINFO_EVENT_GENERIC
+    size_t                  Content_Size;
+    const MediaInfo_int8u*  Content;
+    MediaInfo_int64u        Flags;
+};
+
+/*-------------------------------------------------------------------------*/
+/* AttachedFile                                                            */
+#define MediaInfo_Event_Global_AttachedFile 0xAF04
+
+struct MediaInfo_Event_Global_AttachedFile_0
+{
+    MEDIAINFO_EVENT_GENERIC
+    size_t                  Content_Size;
+    const MediaInfo_int8u*  Content;
+    MediaInfo_int64u        Flags;
+    const char*             Name;
+    const char*             MimeType;
+    const char*             Description;
+};
+
 /*-------------------------------------------------------------------------*/
 /* MediaInfo_Event_Video_SliceInfo_0                                       */
 #define MediaInfo_Event_Video_SliceInfo 0x7801
@@ -424,6 +451,25 @@ struct MediaInfo_Event_General_SubFile_End_0
     MEDIAINFO_EVENT_GENERIC
 };
 
+/*-------------------------------------------------------------------------*/
+/* WaitForMoreData_Start                                                   */
+#define MediaInfo_Event_General_WaitForMoreData_Start 0x7008
+struct MediaInfo_Event_General_WaitForMoreData_Start_0
+{
+    MEDIAINFO_EVENT_GENERIC
+    double                  Duration_Max;       //In seconds
+};
+/*-------------------------------------------------------------------------*/
+/* WaitForMoreData_End                                                     */
+#define MediaInfo_Event_General_WaitForMoreData_End 0x7009
+struct MediaInfo_Event_General_WaitForMoreData_End_0
+{
+    MEDIAINFO_EVENT_GENERIC
+    double                  Duration_Max;       //In seconds
+    double                  Duration_Actual;    //In seconds
+    MediaInfo_int8u         Flags;              //bit 0: Outcome (1 is giving up)
+};
+
 /***************************************************************************/
 /* MPEG-TS / BDAV / TSP                                                    */
 /***************************************************************************/
@@ -596,6 +642,12 @@ struct MediaInfo_Event_DvDif_Analysis_Frame_0
 
 #define MediaInfo_Parser_Dxw            0x6B
 
+/***************************************************************************/
+/* MediaInfo XML                                                           */
+/***************************************************************************/
+
+#define MediaInfo_Parser_MiXml          0x6C
+
 /***************************************************************************/
 /* MPEG Video                                                              */
 /***************************************************************************/
@@ -953,10 +1005,10 @@ inline MediaInfo_int64u MediaInfo_ID_FromGet_intA (const char* ID, const char* C
         else if (
             strcmp(MuxingMode, "DVD-Video")==0                                                  // DVD-Video
          || strcmp(ContainerFormat, "HDS F4M")==0                                               // HDS F4M having more than one stream per referenced file
-         || strcmp(ContainerFormat, "HLS")==0 && strstr(MuxingMode, "HLS")==MuxingMode          // HLS Index
-         || strcmp(ContainerFormat, "HLS")==0 && strstr(MuxingMode, "MPEG-TS")==MuxingMode      // HLS Index
+         || (strcmp(ContainerFormat, "HLS")==0 && strstr(MuxingMode, "HLS")==MuxingMode)        // HLS Index
+         || (strcmp(ContainerFormat, "HLS")==0 && strstr(MuxingMode, "MPEG-TS")==MuxingMode)    // HLS Index
          || strcmp(ContainerFormat, "ISM")==0                                                   // ISM having more than one stream per referenced file
-         || strcmp(ContainerFormat, "DXW")==0 && strstr(MuxingMode, "MPEG-TS")==MuxingMode      // DXW with MPEG-TS
+         || (strcmp(ContainerFormat, "DXW")==0 && strstr(MuxingMode, "MPEG-TS")==MuxingMode)    // DXW with MPEG-TS
          || strcmp(ContainerFormat, "DCP CPL")==0                                               // DCP CPL
          || strcmp(ContainerFormat, "IMF CPL")==0)                                              // IMF CPL
             ToReturn=(ToReturn<<16) | ToReturn2;
