@@ -17,33 +17,30 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/File__Analyze.h"
+#include "MediaInfo/File__HasReferences.h"
 #include "MediaInfo/Multiple/File_DcpPkl.h"
-#include <vector>
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
 {
 
-class File__ReferenceFilesHelper;
-
 //***************************************************************************
 // Class File_DcpCpl
 //***************************************************************************
 
-class File_DcpCpl : public File__Analyze
+class File_DcpCpl : public File__Analyze, File__HasReferences
 {
 public :
     //Constructor/Destructor
     File_DcpCpl();
-    ~File_DcpCpl();
 
 private :
     //Streams management
-    void Streams_Finish ();
+    void Streams_Finish() {ReferenceFiles_Finish();}
 
     //Buffer - Global
     #if MEDIAINFO_SEEK
-    size_t Read_Buffer_Seek (size_t Method, int64u Value, int64u ID);
+    size_t Read_Buffer_Seek (size_t Method, int64u Value, int64u ID) {return ReferenceFiles_Seek(Method, Value, ID);}
     #endif //MEDIAINFO_SEEK
 
     //Buffer - File header
@@ -54,7 +51,25 @@ private :
     void MergeFromAm (File_DcpPkl::streams &StreamsToMerge);
 
     //Temp
-    File__ReferenceFilesHelper*     ReferenceFiles;
+    #if MEDIAINFO_ADVANCED
+        struct descriptor
+        {
+            std::vector<descriptor*> SubDescriptors;
+            int16u Jpeg2000_Rsiz;
+
+            descriptor()
+            : Jpeg2000_Rsiz((int16u)-1)
+            {
+            }
+
+            ~descriptor()
+            {
+                for (std::vector<descriptor*>::iterator SubDescriptor=SubDescriptors.begin(); SubDescriptor!=SubDescriptors.end(); ++SubDescriptor)
+                    delete *SubDescriptor; //*SubDescriptor=NULL;
+            }
+        };
+        std::map<string, descriptor*> EssenceDescriptorList;
+    #endif //MEDIAINFO_ADVANCED
 };
 
 } //NameSpace
