@@ -146,7 +146,7 @@ static const char*  Dv_Emphasis[]=
 };
 
 //---------------------------------------------------------------------------
-static const char*  Dv_consumer_camera_1_ae_mode[]=
+const char*  Dv_consumer_camera_1_ae_mode[]=
 {
     "full automatic",
     "gain priority mode",
@@ -167,7 +167,7 @@ static const char*  Dv_consumer_camera_1_ae_mode[]=
 };
 
 //---------------------------------------------------------------------------
-static const char*  Dv_consumer_camera_1_wb_mode[]=
+const char*  Dv_consumer_camera_1_wb_mode[]=
 {
     "automatic",
     "hold",
@@ -179,6 +179,19 @@ static const char*  Dv_consumer_camera_1_wb_mode[]=
     "", //no info
 };
 
+//---------------------------------------------------------------------------
+static const char*  Dv_APT[] =
+{
+    "IEC",
+    "SMPTE",
+    "",
+    "",
+    "",
+    "",
+    "",
+    "", //no info
+};
+
 //---------------------------------------------------------------------------
 const char* Dv_consumer_camera_1_white_balance(int8u white_balance)
 {
@@ -196,7 +209,7 @@ const char* Dv_consumer_camera_1_white_balance(int8u white_balance)
 }
 
 //---------------------------------------------------------------------------
-static const char*  Dv_consumer_camera_1_fcm[]=
+const char*  Dv_consumer_camera_1_fcm[]=
 {
     "auto focus",
     "manual focus",
@@ -223,7 +236,6 @@ File_DvDif::File_DvDif()
     //Temp
     FrameSize_Theory=0;
     Duration=0;
-    TimeCode_FirstFrame_ms=(int64u)-1;
     Synched_Test_Reset();
     DSF_IsValid=false;
     APT=0xFF; //Impossible
@@ -356,8 +368,8 @@ void File_DvDif::Streams_Fill()
         }
         else
         {
-            Fill(Stream_Video, 0, Video_ScanType, Interlaced?"Interlaced":"Progressive");
-            Fill(Stream_Video, 0, Video_Interlacement, Interlaced?"Interlaced":"PFF");
+            Fill(Stream_Video, 0, Video_ScanType, "Progressive");
+            Fill(Stream_Video, 0, Video_Interlacement, "PFF");
         }
         switch (aspect)
         {
@@ -375,13 +387,14 @@ void File_DvDif::Streams_Fill()
         }
     }
 
+    Fill(Stream_Video, 0, Video_ColorSpace, "YUV");
     if (!FSC_WasSet) //Original DV 25 Mbps
     {
         if (system==false) //NTSC
         {
             switch (video_source_stype)
             {
-                case  0 : Fill(Stream_Video, 0, Video_Colorimetry, "4:1:1"); break; //NTSC 25 Mbps
+                case  0 : Fill(Stream_Video, 0, Video_ChromaSubsampling, "4:1:1"); break; //NTSC 25 Mbps
                 default : ;
             }
         }
@@ -390,16 +403,16 @@ void File_DvDif::Streams_Fill()
             switch (video_source_stype)
             {
                 case  0 : if (APT==0)
-                            Fill(Stream_Video, 0, Video_Colorimetry, "4:2:0");      //PAL 25 Mbps (IEC 61834)
+                            Fill(Stream_Video, 0, Video_ChromaSubsampling, "4:2:0");      //PAL 25 Mbps (IEC 61834)
                           else
-                            Fill(Stream_Video, 0, Video_Colorimetry, "4:1:1");      //PAL 25 Mbps (SMPTE 314M)
+                            Fill(Stream_Video, 0, Video_ChromaSubsampling, "4:1:1");      //PAL 25 Mbps (SMPTE 314M)
                           break;
                 default : ;
             }
         }
     }
     else //DV 50 Mbps and 100 Mbps
-        Fill(Stream_Video, 0, Video_Colorimetry, "4:2:2");
+        Fill(Stream_Video, 0, Video_ChromaSubsampling, "4:2:2");
 
     if (FrameSize_Theory && !IsHd)
     {
@@ -427,7 +440,8 @@ void File_DvDif::Streams_Fill()
             Stream_Prepare(Stream_Audio);
             for (std::map<std::string, Ztring>::iterator Info=Streams_Audio[Pos]->Infos.begin(); Info!=Streams_Audio[Pos]->Infos.end(); ++Info)
                 Fill(Stream_Audio, StreamPos_Last, Info->first.c_str(), Info->second, true);
-            Fill(Stream_Audio, StreamPos_Last, Audio_BitRate_Encoded, 0);
+            if (IsSub)
+                Fill(Stream_Audio, StreamPos_Last, Audio_BitRate_Encoded, 0);
         }
 
     if (Stream_BitRateFromContainer && Retrieve(Stream_Video, 0, Video_BitRate).empty())
@@ -468,7 +482,13 @@ void File_DvDif::Streams_Fill()
             Fill(Stream_Video, 0, Video_BitRate_Mode, "CBR");
         }
     }
-    else if (audio_locked || (Retrieve(Stream_Video, 0, Video_Standard)==__T("PAL") && Retrieve(Stream_Video, 0, Video_Colorimetry)==__T("4:1:1")))
+    else if (audio_locked && Retrieve(Stream_Video, 0, Video_Standard) == __T("PAL") && Retrieve(Stream_Video, 0, Video_ChromaSubsampling) == __T("4:2:0"))
+    {
+        Fill(Stream_General, 0, General_Format_Commercial_IfAny, "DVCAM");
+        Fill(Stream_Video, 0, Video_Format_Commercial_IfAny, "DVCAM");
+        Fill(Stream_Video, 0, Video_BitRate_Mode, "CBR");
+    }
+    else if (audio_locked || (Retrieve(Stream_Video, 0, Video_Standard)==__T("PAL") && Retrieve(Stream_Video, 0, Video_ChromaSubsampling)==__T("4:1:1")))
     {
         Fill(Stream_General, 0, General_Format_Commercial_IfAny, "DVCPRO");
         Fill(Stream_Video, 0, Video_Format_Commercial_IfAny, "DVCPRO");
@@ -478,13 +498,18 @@ void File_DvDif::Streams_Fill()
         Fill(Stream_Video, 0, Video_BitRate_Mode, "CBR");
 
     //Delay
-    if (TimeCode_FirstFrame_ms!=(int64u)-1)
+    TimeCode_FirstFrame.FramesPerSecond=(system?25:30);
+    if (FrameRate_Multiplicator>=2)
+        TimeCode_FirstFrame.MustUseSecondField=true;
+    if (TimeCode_FirstFrame.IsValid())
     {
+        string TimeCode_FirstFrame_String=TimeCode_FirstFrame.ToString();
+        int64u TimeCode_FirstFrame_ms=TimeCode_FirstFrame.ToMilliseconds();
         Fill(Stream_Video, 0, Video_Delay, TimeCode_FirstFrame_ms);
-        if (TimeCode_FirstFrame.size()==11)
-            Fill(Stream_Video, 0, Video_Delay_DropFrame, TimeCode_FirstFrame[8]==';'?"Yes":"No");
+        if (TimeCode_FirstFrame_String.size()==11)
+            Fill(Stream_Video, 0, Video_Delay_DropFrame, TimeCode_FirstFrame_String[8]==';'?"Yes":"No");
         Fill(Stream_Video, 0, Video_Delay_Source, "Stream");
-        Fill(Stream_Video, 0, Video_TimeCode_FirstFrame, TimeCode_FirstFrame.c_str());
+        Fill(Stream_Video, 0, Video_TimeCode_FirstFrame, TimeCode_FirstFrame_String.c_str());
         Fill(Stream_Video, 0, Video_TimeCode_Source, "Subcode time code");
         for (size_t Pos=0; Pos<Count_Get(Stream_Audio); Pos++)
         {
@@ -1321,6 +1346,7 @@ void File_DvDif::timecode()
     int64u MilliSeconds=0;
     int8u  Frames=0;
     bool   DropFrame=false;
+    bool   FieldIndication;
     BS_Begin();
     Skip_SB(                                                    "CF - Color fame");
     if (!DSF_IsValid)
@@ -1335,11 +1361,11 @@ void File_DvDif::timecode()
     Frames+=Frames_Units;
 
     if (!DSF_IsValid)
-        Skip_SB(                                                "BGF0 or PC");
+        Get_SB(FieldIndication,                                 "BGF0 or PC");
     else if (DSF)    //625/50
-        Skip_SB(                                                "BGF0 - Binary group flag");
+        Get_SB(FieldIndication,                                 "BGF0 - Binary group flag");
     else        //525/60
-        Skip_SB(                                                "PC - Biphase mark polarity correction"); //0=even; 1=odd
+        Get_SB(FieldIndication,                                 "PC - Biphase mark polarity correction"); //0=even; 1=odd
     Get_S1 (3, Seconds_Tens,                                    "Seconds (Tens)");
     MilliSeconds+=Seconds_Tens*10*1000;
     Get_S1 (4, Seconds_Units,                                   "Seconds (Units)");
@@ -1370,24 +1396,16 @@ void File_DvDif::timecode()
     Element_Info1(Ztring().Duration_From_Milliseconds(MilliSeconds+((DSF_IsValid && Frames!=45)?((int64u)(Frames/(DSF?25.000:29.970)*1000)):0)));
     BS_End();
 
-    if (TimeCode_FirstFrame_ms==(int64u)-1 && MilliSeconds!=167185000) //if all bits are set to 1, this is not a valid timestamp
+    if (!TimeCode_FirstFrame.HasValue() && MilliSeconds!=167185000) //if all bits are set to 1, this is not a valid timestamp
     {
-        TimeCode_FirstFrame_ms=MilliSeconds;
-        if (DSF_IsValid && Frames!=45) //all bits are set to 1
-
-        TimeCode_FirstFrame_ms+=(int64u)(Frames/(DSF?25.000:29.970)*1000);
-
-        TimeCode_FirstFrame+=('0'+Hours_Tens);
-        TimeCode_FirstFrame+=('0'+Hours_Units);
-        TimeCode_FirstFrame+=':';
-        TimeCode_FirstFrame+=('0'+Minutes_Tens);
-        TimeCode_FirstFrame+=('0'+Minutes_Units);
-        TimeCode_FirstFrame+=':';
-        TimeCode_FirstFrame+=('0'+Seconds_Tens);
-        TimeCode_FirstFrame+=('0'+Seconds_Units);
-        TimeCode_FirstFrame+=DropFrame?';':':';
-        TimeCode_FirstFrame+=('0'+Frames_Tens);
-        TimeCode_FirstFrame+=('0'+Frames_Units);
+        TimeCode_FirstFrame=TimeCode(Hours_Tens  *10+Hours_Units,
+                                     Minutes_Tens*10+Minutes_Units,
+                                     Seconds_Tens*10+Seconds_Units,
+                                     (DSF_IsValid && Frames!=45)?(Frames_Tens*10+Frames_Units):0, //if all bits are set to 1, this is not a valid frame number
+                                     0, //Unknown
+                                     DropFrame,
+                                     false, //Unknown
+                                     false);
     }
 }
 
@@ -1450,6 +1468,9 @@ void File_DvDif::audio_source()
                 Streams_Audio[Pos]->Infos["Channel(s)"].From_Number(audio_source_stype==3?1:2);
                 Streams_Audio[Pos]->Infos["SamplingRate"].From_Number(Dv_Audio_SamplingRate[SamplingRate]);
                 Streams_Audio[Pos]->Infos["BitDepth"].From_Number(Dv_Audio_BitDepth[Resolution]);
+                Streams_Audio[Pos]->Infos["Format_Settings"] = __T("Big / Signed");
+                Streams_Audio[Pos]->Infos["Format_Settings_Endianness"]=__T("Big");
+                Streams_Audio[Pos]->Infos["Format_Settings_Sign"]=__T("Signed");
                 Streams_Audio[Pos]->Infos["BitRate"].From_Number((audio_source_stype==3?1:2)*Dv_Audio_SamplingRate[SamplingRate]*Dv_Audio_BitDepth[Resolution]);
             }
         }
