@@ -17,6 +17,7 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/File__Analyze.h"
+#include "MediaInfo/TimeCode.h"
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -95,8 +96,8 @@ protected :
     void consumer_camera_2();
 
     //Helpers
-    Ztring recdate();
-    Ztring rectime();
+    void recdate(bool FromVideo=false);
+    void rectime(bool FromVideo=false);
 
     //Streams
     struct stream
@@ -112,9 +113,8 @@ protected :
     Ztring Recorded_Date_Date;
     Ztring Recorded_Date_Time;
     Ztring Encoded_Library_Settings;
-    string TimeCode_FirstFrame;
+    TimeCode TimeCode_FirstFrame;
     int64u Duration;
-    int64u TimeCode_FirstFrame_ms;
     int64u FrameSize_Theory; //The size of a frame
     int8u  SCT;
     int8u  SCT_Old;
@@ -244,7 +244,7 @@ protected :
     std::vector<size_t> Video_STA_Errors; //Per STA type
     std::vector<size_t> Video_STA_Errors_Total; //Per STA type
     std::vector<size_t> Audio_Errors; //Per Dseq
-    std::vector<size_t> audio_source_IsPresent;
+    std::vector<bool> audio_source_IsPresent;
     std::vector<bool>   CH_IsPresent;
     std::vector<std::vector<size_t> > Audio_Errors_Total; //Per Channel and Dseq
     std::vector<std::vector<size_t> > Audio_Invalids; //Per Channel and Dseq
