@@ -618,7 +618,7 @@ void File_Dvdv::Audio()
     Get_BS (2, SamplingRate,                                    "Sampling rate"); Param_Info1(Ztring::ToZtring(IFO_SamplingRate[SamplingRate]));
     Get_BS (4, Channels,                                        "Channels"); Param_Info2(Channels+1, " channels");
     BS_End();
-    Get_Local(3, Language,                                      "Language code");
+    Get_UTF8(3, Language,                                       "Language code");
     if (!Language.empty() && Language[0]>=0x80)
         Language.clear(); //this is 0xFF...
     if (Language==__T("iw"))
@@ -697,7 +697,7 @@ void File_Dvdv::Text()
     Get_BS (2, LanguageType,                                    "Language type"); Param_Info1(LanguageType==1?"2CC":"Unknown");
     BS_End();
     Skip_B1(                                                    "Reserved");
-    Get_Local(3, Language,                                      "Language code");
+    Get_UTF8(3, Language,                                       "Language code");
     if (!Language.empty() && Language[0]>=0x80)
         Language.clear(); //this is 0xFF...
     if (Language==__T("iw"))
@@ -1279,7 +1279,7 @@ void File_Dvdv::PGC(int64u Offset, bool Title)
                         ToAdd=0x88;
                     if (Retrieve(Stream_Audio, Pos, Audio_Format)==__T("LPCM"))
                         ToAdd=0xA0;
-                    Ztring ID_String; ID_String.From_Number(ToAdd+Number); ID_String+=__T(" (0x"); ID_String+=Ztring::ToZtring(ToAdd+Number, 16); ID_String+=__T(")");
+                    Ztring ID_String = Get_Hex_ID(ToAdd + Number);
                     Fill(Stream_Audio, Pos, Audio_ID, ID_String);
                     Fill(Stream_Audio, Pos, Audio_ID_String, ID_String, true);
                 }
@@ -1313,7 +1313,7 @@ void File_Dvdv::PGC(int64u Offset, bool Title)
                     while (Pos>Count_Get(Stream_Text))
                         Stream_Prepare(Stream_Text);
 
-                    Ztring ID_String; ID_String.From_Number(0x20+Number_Wide); ID_String+=__T(" (0x"); ID_String+=Ztring::ToZtring(0x20+Number_Wide, 16); ID_String+=__T(")");
+                    Ztring ID_String = Get_Hex_ID(0x20 + Number_Wide);
                     Fill(Stream_Text, Pos, Text_ID, ID_String);
                     Fill(Stream_Text, Pos, Text_ID_String, ID_String, true);
                 }
