@@ -146,31 +146,6 @@ static stream_t Gxf_MediaTypes_StreamKind(int8u Type)
     }
 }
 
-//---------------------------------------------------------------------------
-static const char* Gxf_MediaTypes_Format(int8u Type)
-{
-    switch (Type)
-    {
-        case  3 : return "JPEG"; //525 lines
-        case  4 : return "JPEG"; //625 lines
-        case  9 : return "PCM"; //24-bit
-        case 10 : return "PCM"; //16-bit
-        case 11 : return "MPEG Video"; //525 lines
-        case 12 : return "MPEG Video"; //625 lines
-        case 13 : return "DV"; //25 Mbps, 525 lines
-        case 14 : return "DV"; //25 Mbps, 625 lines
-        case 15 : return "DV"; //50 Mbps, 525 lines
-        case 16 : return "DV"; //50 Mbps, 625 lines
-        case 17 : return "AC-3"; //16-bit
-        case 18 : return "SMPTE 338M, table 1, data type 28"; //SMPTE 338M, table 1, data type 28
-        case 20 : return "MPEG Video"; //HD, Main Profile at High Level
-        case 22 : return "MPEG Video"; //525 lines
-        case 23 : return "MPEG Video"; //625 lines
-        case 25 : return "DV"; //DVCPRO HD
-        default : return "";
-    }
-}
-
 //---------------------------------------------------------------------------
 double Gxf_FrameRate(int32u Content)
 {
@@ -201,19 +176,6 @@ static int32u Gxf_LinesPerFrame_Height(int32u Content)
     }
 }
 
-//---------------------------------------------------------------------------
-static int32u Gxf_LinesPerFrame_Width(int32u Content)
-{
-    switch (Content)
-    {
-        case 1 : return  720;
-        case 2 : return  720;
-        case 4 : return 1920;
-        case 6 : return 1080;
-        default: return    0;
-    }
-}
-
 //---------------------------------------------------------------------------
 static const char* Gxf_FieldsPerFrame(int32u Tag)
 {
@@ -505,6 +467,10 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                         }
                     }
 
+                if (Temp.IsChannelGrouping)
+                    Fill(Stream_Audio, StreamPos_Last, "Title", Streams[StreamID-1].MediaName); //First half of the channel grouping
+                Fill(StreamKind_Last, StreamPos_Last, "Title", Temp.MediaName); //Second half of the channel grouping or standalone
+
                 Merge(*Temp.Parsers[0], Stream_Audio, Pos, StreamPos_Last, false);
 
                 Ztring ID;
@@ -519,9 +485,6 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                 }
                 Fill(Stream_Audio, StreamPos_Last, Audio_ID, ID, true);
                 Fill(Stream_Audio, StreamPos_Last, Audio_ID_String, ID_String, true);
-                if (Temp.IsChannelGrouping)
-                    Fill(Stream_Audio, StreamPos_Last, "Title", Streams[StreamID-1].MediaName); //First half of the channel grouping
-                Fill(StreamKind_Last, StreamPos_Last, "Title", Temp.MediaName); //Second half of the channel grouping or standalone
 
                 for (std::map<std::string, Ztring>::iterator Info=Temp.Infos.begin(); Info!=Temp.Infos.end(); ++Info)
                     if (Info->first=="BitRate" && Temp.Parsers[0]->Count_Get(Stream_Audio)>1)
@@ -888,7 +851,7 @@ void File_Gxf::map()
                 case 0x40 : //Media file name of material
                             {
                             Ztring MediaFileName;
-                            Get_Local(DataLength, MediaFileName, "Content");
+                            Get_UTF8(DataLength, MediaFileName, "Content");
                             Fill(Stream_General, 0, General_Title, MediaFileName, true);
                             }
                             break;
@@ -1193,7 +1156,7 @@ void File_Gxf::map()
                 {
                     case 0x4C : //Media name
                                 {
-                                    Get_Local(DataLength, Streams[TrackID].MediaName, "Content");
+                                    Get_UTF8(DataLength, Streams[TrackID].MediaName, "Content");
                                 }
                                 break;
                     case 0x4D : //Auxiliary Information
