@@ -217,6 +217,9 @@ void File_Lxf::Streams_Fill()
 //---------------------------------------------------------------------------
 void File_Lxf::Streams_Fill_PerStream(File__Analyze* Parser, stream_t Container_StreamKind, size_t Parser_Pos, int8u Format)
 {
+    if (Format!=(int8u)-1)
+        Fill(Container_StreamKind, Container_StreamKind==Stream_Video?0:Parser_Pos, Fill_Parameter(Container_StreamKind, Generic_CodecID), Format);
+
     if (Parser==NULL)
         return;
 
@@ -264,8 +267,6 @@ void File_Lxf::Streams_Fill_PerStream(File__Analyze* Parser, stream_t Container_
                     }
         #endif //MEDIAINFO_DEMUX
     }
-    if (Format!=(int8u)-1)
-        Fill(Container_StreamKind, Container_StreamKind==Stream_Video?0:Parser_Pos, Fill_Parameter(Container_StreamKind, Generic_CodecID), Format);
     if (Container_StreamKind==Stream_Video)
         for (size_t Pos=Count_Get(Stream_Audio)-Parser->Count_Get(Stream_Audio); Pos<Count_Get(Stream_Audio); Pos++)
             Fill(Stream_Audio, Pos, Audio_MuxingMode, Parser->Retrieve(Stream_General, 0, General_Format));
@@ -524,6 +525,7 @@ size_t File_Lxf::Read_Buffer_Seek (size_t Method, int64u Value, int64u)
                         float64 TimeStamp=((float64)Value)/FrameRate;
                         Value=float64_int64s(TimeStamp*1000000000); // In nanoseconds
                     }
+                    return 1;
         case 2  :   //Timestamp
                     {
                     if (Value!=(int64u)-1)
@@ -873,7 +875,7 @@ void File_Lxf::Data_Parse()
             if (!Status[IsFilled] && ((Frame_Count>6 && (Stream_Count==0 ||Config->ParseSpeed==0.0)) || Frame_Count>512)) //5 video frames for 1 Audio frame
             {
                 Fill("LXF");
-                if (MediaInfoLib::Config.ParseSpeed_Get()<1)
+                if (Config->ParseSpeed<1.0)
                 {
                     LookingForLastFrame=true;
                     if (3*(File_Offset+Buffer_Offset)<=File_Size)
@@ -1641,7 +1643,7 @@ void File_Lxf::Video_Stream_1()
     Get_L1 (Lines_Allocated,                            "Lines allocated");
     Get_L1 (Lines_Used,                                 "Lines used");
 
-    if (Lines_Allocated==0 || Lines_Used>Lines_Allocated || Video_Sizes[1]<2+Lines_Used)
+    if (Lines_Allocated==0 || Lines_Used>Lines_Allocated || Video_Sizes[1]<(int32u)2+Lines_Used)
     {
         Skip_XX(Video_Sizes[1]-2,                       "Unknown");
         return;
