@@ -66,23 +66,31 @@ private :
     void Ebml_DocType();
     void Ebml_DocTypeVersion();
     void Ebml_DocTypeReadVersion();
+    void Rawcooked_BeforeData();
+    void Rawcooked_BeforeData(bool HasMask, bool UseMask=false);
+    void Rawcooked_AfterData();
+    void Rawcooked_AfterData(bool HasMask, bool UseMask=false);
+    void Rawcooked_FileName();
+    void Rawcooked_FileName(bool HasMask, bool UseMask=false);
     void RawcookedBlock();
-    void RawcookedBlock_BeforeData();
-    void RawcookedBlock_AfterData();
-    void RawcookedBlock_FileName();
-    void RawcookedBlock_MaskAdditionBeforeData();
-    void RawcookedBlock_MaskAdditionAfterData();
-    void RawcookedBlock_MaskAdditionFileName();
+    void RawcookedBlock_BeforeData() { Rawcooked_BeforeData(false); }
+    void RawcookedBlock_AfterData() { Rawcooked_AfterData(false); }
+    void RawcookedBlock_FileHash();
+    void RawcookedBlock_FileName() { Rawcooked_FileName(false); }
+    void RawcookedBlock_MaskAdditionBeforeData() { Rawcooked_BeforeData(true, true); }
+    void RawcookedBlock_MaskAdditionAfterData() { Rawcooked_AfterData(true, true); }
+    void RawcookedBlock_MaskAdditionFileName() { Rawcooked_FileName(true, true); }
     void RawcookedSegment();
     void RawcookedSegment_LibraryName();
     void RawcookedSegment_LibraryVersion();
-    void RawcookedTrackEntry();
-    void RawcookedTrackEntry_BeforeData();
-    void RawcookedTrackEntry_AfterData();
-    void RawcookedTrackEntry_FileName();
-    void RawcookedTrackEntry_MaskBaseBeforeData();
-    void RawcookedTrackEntry_MaskBaseAfterData();
-    void RawcookedTrackEntry_MaskBaseFileName();
+    void RawcookedTrack();
+    void RawcookedTrack_BeforeData() { RawcookedBlock_BeforeData(); }
+    void RawcookedTrack_AfterData() { RawcookedBlock_AfterData(); }
+    void RawcookedTrack_FileHash() { RawcookedBlock_FileHash(); }
+    void RawcookedTrack_FileName() { RawcookedBlock_FileName(); }
+    void RawcookedTrack_MaskBaseBeforeData() { Rawcooked_BeforeData(true, false); }
+    void RawcookedTrack_MaskBaseAfterData() { Rawcooked_AfterData(true, false); }
+    void RawcookedTrack_MaskBaseFileName() { Rawcooked_FileName(true, false); }
     void Segment();
     void Segment_SeekHead();
     void Segment_SeekHead_Seek();
@@ -174,7 +182,7 @@ private :
     void Segment_Tracks_TrackEntry_TrackTranslate_TrackTranslateTrackID(){Skip_XX(Element_Size, "Data");};
     void Segment_Tracks_TrackEntry_Video();
     void Segment_Tracks_TrackEntry_Video_FlagInterlaced(){UInteger_Info();};
-    void Segment_Tracks_TrackEntry_Video_FieldOrder(){UInteger_Info();};
+    void Segment_Tracks_TrackEntry_Video_FieldOrder();
     void Segment_Tracks_TrackEntry_Video_StereoMode();
     void Segment_Tracks_TrackEntry_Video_AlphaMode(){UInteger_Info();};
     void Segment_Tracks_TrackEntry_Video_OldStereoMode();
@@ -203,26 +211,26 @@ private :
     void Segment_Tracks_TrackEntry_Video_Colour_Range();
     void Segment_Tracks_TrackEntry_Video_Colour_TransferCharacteristics();
     void Segment_Tracks_TrackEntry_Video_Colour_Primaries();
-    void Segment_Tracks_TrackEntry_Video_Colour_MaxCLL(){UInteger_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MaxFALL(){UInteger_Info();};
+    void Segment_Tracks_TrackEntry_Video_Colour_MaxCLL();
+    void Segment_Tracks_TrackEntry_Video_Colour_MaxFALL();
     void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata(){};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryRChromaticityX(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryRChromaticityY(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryGChromaticityX(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryGChromaticityY(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryBChromaticityX(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryBChromaticityY(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_WhitePointChromaticityX(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_WhitePointChromaticityY(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_LuminanceMax(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_LuminanceMin(){Float_Info();};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryRChromaticityX()   {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Primary(2*2  );};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryRChromaticityY()   {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Primary(2*2+1);};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryGChromaticityX()   {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Primary(0*2  );};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryGChromaticityY()   {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Primary(0*2+1);};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryBChromaticityX()   {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Primary(1*2  );};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_PrimaryBChromaticityY()   {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Primary(1*2+1);};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_WhitePointChromaticityX() {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Primary(3*2  );};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_WhitePointChromaticityY() {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Primary(3*2+1);};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_LuminanceMax()            {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Luminance(1);};
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_LuminanceMin()            {Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Luminance(0);};
     void Segment_Tracks_TrackEntry_Video_Projection(){};
     void Segment_Tracks_TrackEntry_Video_Projection_ProjectionType(){UInteger_Info();};
     void Segment_Tracks_TrackEntry_Video_Projection_ProjectionPrivate(){Skip_XX(Element_Size, "Data");};
     void Segment_Tracks_TrackEntry_Video_Projection_ProjectionPoseYaw(){Float_Info();};
     void Segment_Tracks_TrackEntry_Video_Projection_ProjectionPosePitch(){Float_Info();};
     void Segment_Tracks_TrackEntry_Video_Projection_ProjectionPoseRoll(){Float_Info();};
-    void Segment_Tracks_TrackEntry_Audio(){};
+    void Segment_Tracks_TrackEntry_Audio();
     void Segment_Tracks_TrackEntry_Audio_SamplingFrequency();
     void Segment_Tracks_TrackEntry_Audio_OutputSamplingFrequency();
     void Segment_Tracks_TrackEntry_Audio_Channels();
@@ -276,8 +284,6 @@ private :
     void Segment_Attachments_AttachedFile_FileName();
     void Segment_Attachments_AttachedFile_FileMimeType();
     void Segment_Attachments_AttachedFile_FileData();
-    void Segment_Attachments_AttachedFile_FileData_RawcookedBlock() {RawcookedBlock();};
-    void Segment_Attachments_AttachedFile_FileData_RawcookedTrackEntry() {RawcookedTrackEntry();};
     void Segment_Attachments_AttachedFile_FileUID(){UInteger_Info();};
     void Segment_Attachments_AttachedFile_FileReferral(){Skip_XX(Element_Size, "Data");};
     void Segment_Attachments_AttachedFile_FileUsedStartTime(){UInteger_Info();};
@@ -355,6 +361,7 @@ private :
         int64u                  PixelCropLeft;
         int64u                  PixelCropRight;
         int64u                  PixelCropTop;
+        mastering_metadata_2086      MasteringMetadata;
         #if MEDIAINFO_TRACE
             size_t Trace_Segment_Cluster_Block_Count;
         #endif // MEDIAINFO_TRACE
@@ -383,6 +390,7 @@ private :
             PixelCropLeft=0;
             PixelCropRight=0;
             PixelCropTop=0;
+            memset(&MasteringMetadata, 0xFF, sizeof(MasteringMetadata));
             #if MEDIAINFO_TRACE
                 Trace_Segment_Cluster_Block_Count=0;
             #endif // MEDIAINFO_TRACE
@@ -415,6 +423,7 @@ private :
     int8u*   CodecPrivate;
     size_t   CodecPrivate_Size;
     void     CodecPrivate_Manage();
+    void     Audio_Manage();
     Ztring   CodecID;
     infocodecid_format_t InfoCodecID_Format_Type;
     void     CodecID_Manage();
@@ -511,14 +520,34 @@ private :
     //RAWcooked data
     struct rawcookedtrack
     {
-        string MaskAdditionFileName;
-        int64u FramePos;
+        struct mask
+        {
+            int8u*      Buffer;
+            size_t      Size;
 
-        rawcookedtrack() :
-            FramePos(0)
-        {}
+            //mask(); //Init done in rawcookedtrack() in 1 shot
+            ~mask()
+            {
+                delete[] Buffer;
+            }
+        };
+        int64u          FramePos;
+        mask            MaskBaseFileName;
+        mask            MaskBaseBeforeData;
+
+        rawcookedtrack()
+        {
+            memset(this, 0x00, sizeof(rawcookedtrack));
+        }
     };
-    rawcookedtrack RawcookedTrack;
+    rawcookedtrack RawcookedTrack_Data;
+    const int8u* Rawcooked_Compressed_Save_Buffer;
+    size_t Rawcooked_Compressed_Save_Buffer_Offset;
+    int64u Rawcooked_Compressed_Save_Element_Offset;
+    int64u Rawcooked_Compressed_Save_Element_Size;
+    bool   Trace_Activated_Save;
+    bool Rawcooked_Compressed_Start(rawcookedtrack::mask* Mask=NULL, bool UseMask=false);
+    void Rawcooked_Compressed_End(rawcookedtrack::mask* Mask=NULL, bool UseMask=false);
 
     //Hints
     size_t*                 File_Buffer_Size_Hint_Pointer;
@@ -528,6 +557,8 @@ private :
     void Segment_Tracks_TrackEntry_CodecPrivate_auds();
     void Segment_Tracks_TrackEntry_CodecPrivate_auds_ExtensibleWave(int16u BitsPerSample);
     void Segment_Tracks_TrackEntry_CodecPrivate_vids();
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Primary(int8u i);
+    void Segment_Tracks_TrackEntry_Video_Colour_MasteringMetadata_Luminance(int8u i);
     void JumpTo(int64u GoTo);
     void TestMultipleInstances(size_t* Instances=NULL);
     void CRC32_Check();
