@@ -175,7 +175,7 @@ private :
     int32u program_mux_rate;
 
     //PS
-    struct ps_stream
+    struct ps_stream : public stream_time
     {
         struct Mpeg_TimeStamp
         {
@@ -212,9 +212,6 @@ private :
         size_t         StreamRegistration_Count;
         size_t         StreamOrder;
         size_t         FirstPacketOrder;
-        bool           Searching_Payload;
-        bool           Searching_TimeStamp_Start;
-        bool           Searching_TimeStamp_End;
         bool           IsFilled;
 
         void Streams_Update()
@@ -250,9 +247,7 @@ private :
             StreamRegistration_Count=0;
             StreamOrder=(size_t)-1;
             FirstPacketOrder=(size_t)-1;
-            Searching_Payload=false;
-            Searching_TimeStamp_Start=false;
-            Searching_TimeStamp_End=false;
+            Init_Stream(false);
             IsFilled=false;
         }
 
@@ -291,6 +286,7 @@ private :
     File__Analyze* ChooseParser_Adts();
     File__Analyze* ChooseParser_Latm();
     File__Analyze* ChooseParser_AC3();
+    File__Analyze* ChooseParser_AC4();
     File__Analyze* ChooseParser_DTS();
     File__Analyze* ChooseParser_SDDS();
     File__Analyze* ChooseParser_AAC();
@@ -315,6 +311,7 @@ private :
     void Streams_Fill_PerStream_PerKind(size_t StreamID, ps_stream &Temp, kindofstream KindOfStream, size_t Count);
     void Streams_Finish_PerStream(size_t StreamID, ps_stream &Temp, kindofstream KindOfStream);
     void xxx_stream_Parse(ps_stream &Temp, int8u &stream_Count);
+    void MergeGeneral(File__Analyze* Parser, general Parameter);
 
     //Output buffer
     size_t Output_Buffer_Get (const String &Value);
