@@ -515,6 +515,21 @@ void File_Riff::Streams_Finish ()
             }
         }
 
+        if (StreamKind_Last==Stream_Audio && Retrieve(Stream_Audio, StreamPos_Last, Audio_Format)==__T("MPEG Audio"))
+        {
+            Ztring Delay = Retrieve(Stream_Audio, StreamPos_Last, Audio_Delay);
+            Ztring Delay_Original = Retrieve(Stream_Audio, StreamPos_Last, Audio_Delay_Original);
+            if (!Delay.empty() && !Delay_Original.empty())
+            {
+                Fill(Stream_Audio, StreamPos_Last, Audio_Delay, Delay.To_float64()+ Delay_Original.To_float64(), 0, true);
+                Ztring Delay_Source = Retrieve(Stream_Audio, StreamPos_Last, Audio_Delay_Source);
+                Ztring Delay_Original_Source = Retrieve(Stream_Audio, StreamPos_Last, Audio_Delay_Original_Source);
+                Fill(Stream_Audio, StreamPos_Last, Audio_Delay_Source, Delay_Source+__T(" + ")+Delay_Original_Source, true);
+                Clear(Stream_Audio, StreamPos_Last, Audio_Delay_Original);
+                Clear(Stream_Audio, StreamPos_Last, Audio_Delay_Original_Source);
+            }
+        }
+
         ++Temp;
     }
 
@@ -560,22 +575,35 @@ void File_Riff::Streams_Finish ()
             Fill(Stream_General, 0, General_Format_Commercial_IfAny, "DV");
             Fill(Stream_General, 0, General_Format_Commercial, "AVI DV");
         }
-        else if (Retrieve(Stream_Video, 0, Video_Format)==__T("MPEG Video") && Retrieve(Stream_Video, 0, Video_Format_Settings_GOP)==__T("N=1") && Retrieve(Stream_Video, 0, Video_Colorimetry)==__T("4:2:2") && Retrieve(Stream_Video, 0, Video_BitRate)==__T("30000000"))
+        else if (Retrieve(Stream_Video, 0, Video_Format)==__T("MPEG Video") && Retrieve(Stream_Video, 0, Video_Format_Settings_GOP)==__T("N=1") && Retrieve(Stream_Video, 0, Video_ChromaSubsampling)==__T("4:2:2") && Retrieve(Stream_Video, 0, Video_BitRate)==__T("30000000"))
         {
             Fill(Stream_General, 0, General_Format_Commercial_IfAny, "MPEG IMX 30");
             Fill(Stream_Video, 0, Video_Format_Commercial_IfAny, "MPEG IMX 30");
         }
-        else if (Retrieve(Stream_Video, 0, Video_Format)==__T("MPEG Video") && Retrieve(Stream_Video, 0, Video_Format_Settings_GOP)==__T("N=1") && Retrieve(Stream_Video, 0, Video_Colorimetry)==__T("4:2:2") && Retrieve(Stream_Video, 0, Video_BitRate)==__T("40000000"))
+        else if (Retrieve(Stream_Video, 0, Video_Format)==__T("MPEG Video") && Retrieve(Stream_Video, 0, Video_Format_Settings_GOP)==__T("N=1") && Retrieve(Stream_Video, 0, Video_ChromaSubsampling)==__T("4:2:2") && Retrieve(Stream_Video, 0, Video_BitRate)==__T("40000000"))
         {
             Fill(Stream_General, 0, General_Format_Commercial_IfAny, "MPEG IMX 40");
             Fill(Stream_Video, 0, Video_Format_Commercial_IfAny, "MPEG IMX 40");
         }
-        else if (Retrieve(Stream_Video, 0, Video_Format)==__T("MPEG Video") && Retrieve(Stream_Video, 0, Video_Format_Settings_GOP)==__T("N=1") && Retrieve(Stream_Video, 0, Video_Colorimetry)==__T("4:2:2") && Retrieve(Stream_Video, 0, Video_BitRate)==__T("50000000"))
+        else if (Retrieve(Stream_Video, 0, Video_Format)==__T("MPEG Video") && Retrieve(Stream_Video, 0, Video_Format_Settings_GOP)==__T("N=1") && Retrieve(Stream_Video, 0, Video_ChromaSubsampling)==__T("4:2:2") && Retrieve(Stream_Video, 0, Video_BitRate)==__T("50000000"))
         {
             Fill(Stream_General, 0, General_Format_Commercial_IfAny, "MPEG IMX 50");
             Fill(Stream_Video, 0, Video_Format_Commercial_IfAny, "MPEG IMX 50");
         }
     }
+    else if (Count_Get(Stream_Audio)==1)
+    {
+        if (Retrieve(Stream_Audio, StreamPos_Last, Audio_Format)==__T("PCM"))
+        {
+            int64u Resolution=Retrieve(Stream_Audio, StreamPos_Last, Audio_BitDepth).To_int64u();
+            if (Resolution==24)
+            {
+                int64u SamplingRate=Retrieve(Stream_Audio, StreamPos_Last, Audio_SamplingRate).To_int64u();
+                if (SamplingRate==44100*8 || SamplingRate==48000*8)
+                    Fill(Stream_Audio, StreamPos_Last, Audio_Format_Commercial_IfAny, "DXD");
+            }
+        }
+    }
 }
 
 //***************************************************************************
@@ -679,9 +707,9 @@ void File_Riff::Read_Buffer_Continue()
     if (Demux_Parser)
     {
         Open_Buffer_Continue(Demux_Parser, Buffer+Buffer_Offset, 0, false);
+        if (Config->Demux_EventWasSent)
+            return;
         Demux_Parser=NULL;
-        //if (Config->Demux_EventWasSent)
-        //    return;
     }
 }
 #endif //MEDIAINFO_DEMUX
@@ -925,7 +953,7 @@ void File_Riff::Header_Parse()
     }
 
     //Alignment
-    if (Size_Complete%2 && !IsNotWordAligned)
+    if (Size_Complete%2 && !IsNotWordAligned && File_Offset+Buffer_Offset+Element_Offset+Size_Complete<File_Size)
     {
         Size_Complete++; //Always 2-byte aligned
         Alignement_ExtraByte=1;
