@@ -110,7 +110,7 @@ string To_XML (Node& Cur_Node, const int& Level, bool Print_Header, bool Indent)
 
     if (!Cur_Node.XmlCommentOut.empty())
     {
-        Result+=(Indent?string(Level, '\t'):string(""))+"<!-- "+Cur_Node.XmlCommentOut;
+        Result+=(Indent?string(Level, '\t'):string())+"<!-- "+Cur_Node.XmlCommentOut;
 
         // If the node name is empty, just print the comment
         if (Cur_Node.Name.empty())
@@ -121,7 +121,7 @@ string To_XML (Node& Cur_Node, const int& Level, bool Print_Header, bool Indent)
         Result+="\n";
     }
 
-    Result+=(Indent?string(Level, '\t'):string(""))+"<"+Cur_Node.Name;
+    Result+=(Indent?string(Level, '\t'):string())+"<"+Cur_Node.Name;
 
     for (size_t Pos=0; Pos<Cur_Node.Attrs.size(); Pos++)
     {
@@ -138,7 +138,7 @@ string To_XML (Node& Cur_Node, const int& Level, bool Print_Header, bool Indent)
         if (!Cur_Node.XmlComment.empty() && Cur_Node.XmlCommentOut.empty())
             Result+=" <!-- "+Cur_Node.XmlComment+" -->";
         if (Cur_Node.XmlCommentOut.size())
-            Result+="\n"+(Indent?string(Level, '\t'):string(""))+"-->";
+            Result+="\n"+(Indent?string(Level, '\t'):string())+"-->";
         return Result;
     }
 
@@ -147,7 +147,7 @@ string To_XML (Node& Cur_Node, const int& Level, bool Print_Header, bool Indent)
     if (Cur_Node.Value.size())
     {
         if (Cur_Node.Childs.size())
-            Result+="\n"+(Indent?string(Level+1, '\t'):string(""));
+            Result+="\n"+(Indent?string(Level+1, '\t'):string());
         Result+=XML_Encode(Cur_Node.Value);
     }
 
@@ -168,14 +168,14 @@ string To_XML (Node& Cur_Node, const int& Level, bool Print_Header, bool Indent)
             Cur_Node.Childs[Pos]=NULL;
         }
         Cur_Node.Childs.clear(); //Free memory
-        Result+="\n"+(Indent?string(Level, '\t'):string(""));
+        Result+="\n"+(Indent?string(Level, '\t'):string());
     }
     else
         CanDisplayXmlComment=true;
 
     Result+="</"+Cur_Node.Name+">";
     if (Cur_Node.XmlCommentOut.size())
-        Result+="\n"+(Indent?string(Level, '\t'):string(""))+"-->";
+        Result+="\n"+(Indent?string(Level, '\t'):string())+"-->";
     else if (!Cur_Node.XmlComment.empty() && CanDisplayXmlComment)
         Result+=" <!-- "+Cur_Node.XmlComment+" -->";
     if (!Level)
@@ -214,7 +214,7 @@ string To_JSON_Attributes(Node& Cur_Node, const int& Level, bool Indent)
         if (Cur_Node.Attrs[Pos].first.empty() || Cur_Node.Attrs[Pos].first.substr(0, 5)=="xmlns" || Cur_Node.Attrs[Pos].first.substr(0, 3)=="xsi")
             continue;
 
-        Result+="\n"+(Indent?string(Level, '\t'):string(""))+"\"@"+Cur_Node.Attrs[Pos].first+"\": \""
+        Result+="\n"+(Indent?string(Level, '\t'):string())+"\"@"+Cur_Node.Attrs[Pos].first+"\": \""
                +JSON_Encode(Cur_Node.Attrs[Pos].second)+"\"";
 
         if (Pos<Cur_Node.Attrs.size()-1 || Cur_Node.Value.size() || Cur_Node.Childs.size())
@@ -246,7 +246,7 @@ string To_JSON_Elements(Node& Cur_Node, const int& Level, bool Indent)
         if (Cur_Node.Name.empty())
             continue;
 
-        Result+="\n"+(Indent?string(Level, '\t'):string(""))+"\""+Cur_Node.Childs[Pos]->Name+"\": ";
+        Result+="\n"+(Indent?string(Level, '\t'):string())+"\""+Cur_Node.Childs[Pos]->Name+"\": ";
 
         bool Multiple=Cur_Node.Childs[Pos]->Multiple;
         if (Multiple)
@@ -258,14 +258,14 @@ string To_JSON_Elements(Node& Cur_Node, const int& Level, bool Indent)
             if (!Cur_Node.Childs[Pos2])
                 continue;
 
-            Result+=(Indent?string(Level+1, '\t'):string(""))+"{";
+            Result+=(Indent?string(Level+1, '\t'):string())+"{";
             Result+=To_JSON_Attributes(*Cur_Node.Childs[Pos2], Level+2, Indent);
             Result+=To_JSON_Elements(*Cur_Node.Childs[Pos2], Level+2, Indent);
             Result+="\n";
 
             if(!Cur_Node.Childs[Pos2]->Value.empty())
-                Result+=(Indent?string(Level+2, '\t'):string(""))+"\"#value\": \""+JSON_Encode(Cur_Node.Childs[Pos2]->Value)+"\"\n";
-            Result+=(Indent?string(Level+1, '\t'):string(""))+"}";
+                Result+=(Indent?string(Level+2, '\t'):string())+"\"#value\": \""+JSON_Encode(Cur_Node.Childs[Pos2]->Value)+"\"\n";
+            Result+=(Indent?string(Level+1, '\t'):string())+"}";
 
             if (Pos2<Cur_Node.Childs.size()-1 && Cur_Node.Childs[Pos2]->Name==Cur_Node.Childs[Pos2+1]->Name)
                 Result+=",";
@@ -278,7 +278,7 @@ string To_JSON_Elements(Node& Cur_Node, const int& Level, bool Indent)
             Pos=Pos2;
         }
         if (Multiple)
-            Result+=(Indent?string(Level, '\t'):string(""))+"]";
+            Result+=(Indent?string(Level, '\t'):string())+"]";
 
         if (Pos<Cur_Node.Childs.size()-1 || !Cur_Node.Value.empty())
             Result+=",";
@@ -307,7 +307,7 @@ string To_JSON (Node& Cur_Node, const int& Level, bool Print_Header, bool Indent
     if (Print_Header)
         Result+="{\n";
 
-    Result+=(Indent?string(Level+1, '\t'):string(""))+"\""+Cur_Node.Name+"\": ";
+    Result+=(Indent?string(Level+1, '\t'):string())+"\""+Cur_Node.Name+"\": ";
 
     if (Cur_Node.Attrs.empty() && Cur_Node.Childs.empty() && !Cur_Node.Multiple)
     {
@@ -324,9 +324,9 @@ string To_JSON (Node& Cur_Node, const int& Level, bool Print_Header, bool Indent
     Result+=To_JSON_Attributes(Cur_Node, Level+2, Indent);
     Result+=To_JSON_Elements(Cur_Node, Level+2, Indent);
     if (!Cur_Node.Value.empty())
-        Result+="\n"+(Indent?string(Level+2, '\t'):string(""))+"\"#value\": \""+JSON_Encode(Cur_Node.Value)+"\"";
+        Result+="\n"+(Indent?string(Level+2, '\t'):string())+"\"#value\": \""+JSON_Encode(Cur_Node.Value)+"\"";
 
-    Result+="\n"+(Indent?string(Level+1, '\t'):string(""))+"}";
+    Result+="\n"+(Indent?string(Level+1, '\t'):string())+"}";
 
     if (Print_Header)
         Result+="\n}\n";
