@@ -125,6 +125,9 @@
     #if !defined (MEDIAINFO_EXPORT_NO) && !defined (MEDIAINFO_EXPORT_YES)
         #define MEDIAINFO_EXPORT_NO
     #endif
+    #if !defined (MEDIAINFO_JNI_NO) && !defined (MEDIAINFO_JNI_YES)
+        #define MEDIAINFO_JNI_NO
+    #endif
 #endif
 
 //---------------------------------------------------------------------------
@@ -139,6 +142,19 @@
         #define MEDIAINFO_TRACE 1
     #endif
 #endif
+#if !defined(MEDIAINFO_TRACE_FFV1CONTENT)
+    #if defined(MEDIAINFO_TRACE_FFV1CONTENT_NO) && defined(MEDIAINFO_TRACE_FFV1CONTENT_YES)
+        #undef MEDIAINFO_TRACE_FFV1CONTENT_NO //MEDIAINFO_TRACE_FFV1CONTENT_YES has priority
+    #endif
+    #if defined(MEDIAINFO_TRACE_FFV1CONTENT_YES)
+        #define MEDIAINFO_TRACE_FFV1CONTENT 1
+    #else
+        #define MEDIAINFO_TRACE_FFV1CONTENT 0
+    #endif
+#endif
+#if MEDIAINFO_TRACE_FFV1CONTENT && !MEDIAINFO_TRACE
+    #define MEDIAINFO_TRACE_FFV1CONTENT 0 //No trace if MEDIAINFO_TRACE is 0
+#endif
 #if !defined(MEDIAINFO_FILTER)
     #if defined(MEDIAINFO_FILTER_NO) && defined(MEDIAINFO_FILTER_YES)
         #undef MEDIAINFO_FILTER_NO //MEDIAINFO_FILTER_YES has priority
@@ -259,6 +275,16 @@
         #define MEDIAINFO_SHA2 1
     #endif
 #endif
+#if !defined(MEDIAINFO_COMPRESS)
+    #if defined(MEDIAINFO_COMPRESS_NO) && defined(MEDIAINFO_COMPRESS_YES)
+        #undef MEDIAINFO_COMPRESS_NO //MEDIAINFO_COMPRESS_YES has priority
+    #endif
+    #if defined(MEDIAINFO_COMPRESS_NO)
+        #define MEDIAINFO_COMPRESS 0
+    #else
+        #define MEDIAINFO_COMPRESS 1
+    #endif
+#endif
 #if !defined(MEDIAINFO_DEMUX)
     #if !defined(MEDIAINFO_DEMUX_NO) && !defined(MEDIAINFO_DEMUX_YES) && !MEDIAINFO_EVENTS
         #define MEDIAINFO_DEMUX_NO //MEDIAINFO_DEMUX is disabled by default if MEDIAINFO_EVENTS is set to 0
@@ -272,6 +298,16 @@
         #define MEDIAINFO_DEMUX 1
     #endif
 #endif
+#if !defined(MEDIAINFO_DECODE)
+    #if defined(MEDIAINFO_DECODE_NO) && defined(MEDIAINFO_DECODE_YES)
+        #undef MEDIAINFO_DECODE_NO //MEDIAINFO_DECODE_YES has priority
+    #endif
+    #if defined(MEDIAINFO_DECODE_NO)
+        #define MEDIAINFO_DECODE 0
+    #else
+        #define MEDIAINFO_DECODE 1
+    #endif
+#endif
 #if MEDIAINFO_DEMUX && !MEDIAINFO_EVENTS
     pragma error MEDIAINFO_DEMUX can be set to 1 only if MEDIAINFO_EVENTS is set to 1
 #endif
@@ -303,12 +339,29 @@
     #if defined(MEDIAINFO_READTHREAD_NO) && defined(MEDIAINFO_READTHREAD_YES)
         #undef MEDIAINFO_READTHREAD_NO //MEDIAINFO_READTHREAD_YES has priority
     #endif
+    #if !defined(MEDIAINFO_READTHREAD_NO) && !defined(MEDIAINFO_READTHREAD_YES)
+        #define MEDIAINFO_READTHREAD_NO //MEDIAINFO_READTHREAD_NO by default, as there are
+    #endif
     #if defined(MEDIAINFO_READTHREAD_NO) || !defined(WINDOWS) //Currently supported only on Windows TODO: add support of non Windows OS
         #define MEDIAINFO_READTHREAD 0
     #else
         #define MEDIAINFO_READTHREAD 1
     #endif
 #endif
+#if !defined(MEDIAINFO_FIXITY)
+    #if defined(MEDIAINFO_FIXITY_NO) && defined(MEDIAINFO_FIXITY_YES)
+        #undef MEDIAINFO_FIXITY_NO //MEDIAINFO_FIXITY_YES has priority
+    #endif
+    #if defined(MEDIAINFO_FIXITY_NO)
+        #define MEDIAINFO_FIXITY 0
+    #else
+        #if MEDIAINFO_ADVANCED
+            #define MEDIAINFO_FIXITY 1
+        #else //MEDIAINFO_ADVANCED
+            #define MEDIAINFO_FIXITY 0
+        #endif //MEDIAINFO_ADVANCED
+    #endif
+#endif
 
 //***************************************************************************
 // Precise configuration
@@ -342,6 +395,9 @@
 #if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_XML_NO) && !defined(MEDIAINFO_XML_YES)
     #define MEDIAINFO_XML_YES
 #endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_JSON_NO) && !defined(MEDIAINFO_JSON_YES)
+    #define MEDIAINFO_JSON_YES
+#endif
 #if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_CSV_NO) && !defined(MEDIAINFO_CSV_YES)
     #define MEDIAINFO_CSV_YES
 #endif
@@ -363,6 +419,9 @@
 #if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_REVTMD_NO) && !defined(MEDIAINFO_REVTMD_YES)
     #define MEDIAINFO_REVTMD_YES
 #endif
+#if !defined(MEDIAINFO_EXPORT_NO) && !defined(MEDIAINFO_NISO_NO) && !defined(MEDIAINFO_NISO_YES)
+    #define MEDIAINFO_NISO_YES
+#endif
 
 //---------------------------------------------------------------------------
 // All in one for no parsers
@@ -453,6 +512,9 @@
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_MK_NO) && !defined(MEDIAINFO_MK_YES)
     #define MEDIAINFO_MK_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_MIXML_NO) && !defined(MEDIAINFO_MIXML_YES)
+    #define MEDIAINFO_MIXML_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_MPEG4_NO) && !defined(MEDIAINFO_MPEG4_YES)
     #define MEDIAINFO_MPEG4_YES
 #endif
@@ -510,9 +572,15 @@
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_UMF_NO) && !defined(MEDIAINFO_UMF_YES)
     #define MEDIAINFO_UMF_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_VBI_NO) && !defined(MEDIAINFO_VBI_YES)
+    #define MEDIAINFO_VBI_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_WM_NO) && !defined(MEDIAINFO_WM_YES)
     #define MEDIAINFO_WM_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_WTV_NO) && !defined(MEDIAINFO_WTV_YES)
+#define MEDIAINFO_WTV_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_XDCAM_NO) && !defined(MEDIAINFO_XDCAM_YES)
     #define MEDIAINFO_XDCAM_YES
 #endif
@@ -528,6 +596,9 @@
 #if !defined(MEDIAINFO_VIDEO_NO) && !defined(MEDIAINFO_AFDBARDATA_NO) && !defined(MEDIAINFO_AFDBARDATA_YES)
     #define MEDIAINFO_AFDBARDATA_YES
 #endif
+#if !defined(MEDIAINFO_VIDEO_NO) && !defined(MEDIAINFO_AV1_NO) && !defined(MEDIAINFO_AV1_YES)
+    #define MEDIAINFO_AV1_YES
+#endif
 #if !defined(MEDIAINFO_VIDEO_NO) && !defined(MEDIAINFO_AVC_NO) && !defined(MEDIAINFO_AVC_YES)
     #define MEDIAINFO_AVC_YES
 #endif
@@ -597,6 +668,9 @@
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_AC3_NO) && !defined(MEDIAINFO_AC3_YES)
     #define MEDIAINFO_AC3_YES
 #endif
+#if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_AC4_NO) && !defined(MEDIAINFO_AC4_YES)
+    #define MEDIAINFO_AC4_YES
+#endif
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_ADPCM_NO) && !defined(MEDIAINFO_ADPCM_YES)
     #define MEDIAINFO_ADPCM_YES
 #endif
@@ -627,6 +701,12 @@
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_DOLBYE_NO) && !defined(MEDIAINFO_DOLBYE_YES)
     #define MEDIAINFO_DOLBYE_YES
 #endif
+#if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_DSF_NO) && !defined(MEDIAINFO_DSF_YES)
+    #define MEDIAINFO_DSF_YES
+#endif
+#if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_DSDIFF_NO) && !defined(MEDIAINFO_DSDIFF_YES)
+    #define MEDIAINFO_DSDIFF_YES
+#endif
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_DTS_NO) && !defined(MEDIAINFO_DTS_YES)
     #define MEDIAINFO_DTS_YES
 #endif
@@ -639,7 +719,7 @@
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_LA_NO) && !defined(MEDIAINFO_LA_YES)
     #define MEDIAINFO_LA_YES
 #endif
-#if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_MIDO_NO) && !defined(MEDIAINFO_MIDO_YES)
+#if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_MIDI_NO) && !defined(MEDIAINFO_MIDI_YES)
     #define MEDIAINFO_MIDI_YES
 #endif
 #if !defined(MEDIAINFO_AUDIO_NO) && !defined(MEDIAINFO_MOD_NO) && !defined(MEDIAINFO_MOD_YES)
@@ -888,5 +968,8 @@
 #if !defined(MEDIAINFO_UNKNOWN_NO)
     #define MEDIAINFO_UNKNOWN_YES
 #endif
+#if !defined(MEDIAINFO_JNI_NO)
+    #define MEDIAINFO_JNI_YES
+#endif
 
 #endif
