@@ -173,16 +173,6 @@ void File_Scte20::Read_Buffer_Unsynched()
 // Buffer - Global
 //***************************************************************************
 
-static inline int8u ReverseBits(int8u c)
-{
-    // Input: bit order is 76543210
-    //Output: bit order is 01234567
-    c = (c & 0x0F) << 4 | (c & 0xF0) >> 4;
-    c = (c & 0x33) << 2 | (c & 0xCC) >> 2;
-    c = (c & 0x55) << 1 | (c & 0xAA) >> 1;
-    return c;
-}
-
 //---------------------------------------------------------------------------
 void File_Scte20::Read_Buffer_Continue()
 {
