@@ -68,7 +68,11 @@ public:
     //Helpers
     bool IsValid() const
     {
-        return FramesPerSecond?true:false;
+        return FramesPerSecond && HasValue();
+    }
+    bool HasValue() const
+    {
+        return Hours!=(int8u)-1;
     }
     void PlusOne();
     void MinusOne();
@@ -81,6 +85,9 @@ public:
     int8u Minutes;
     int8u Seconds;
     int8u Frames;
+    int32s MoreSamples;
+    int32s MoreSamples_Frequency;
+    bool  FramesPerSecond_Is1001;
     int8u FramesPerSecond;
     bool  DropFrame;
     bool  MustUseSecondField;
@@ -88,6 +95,9 @@ public:
     bool  IsNegative;
 };
 
+Ztring Date_MJD(int16u Date);
+Ztring Time_BCD(int32u Time);
+
 } //NameSpace
 
 #endif
