@@ -219,6 +219,7 @@ private :
         bool    general_progressive_source_flag;
         bool    general_interlaced_source_flag;
         bool    general_frame_only_constraint_flag;
+        bool    general_max_8bit_constraint_flag;
 
         //Computed value
         bool    NalHrdBpPresentFlag() {return vui_parameters && vui_parameters->NAL;}
@@ -227,7 +228,7 @@ private :
         int8u   ChromaArrayType() {return separate_colour_plane_flag?0:chroma_format_idc;}
 
         //Constructor/Destructor
-        seq_parameter_set_struct(vui_parameters_struct* vui_parameters_, int32u profile_space_, bool tier_flag_, int32u profile_idc_, int32u level_idc_, int32u pic_width_in_luma_samples_, int32u pic_height_in_luma_samples_, int32u conf_win_left_offset_, int32u conf_win_right_offset_, int32u conf_win_top_offset_, int32u conf_win_bottom_offset_, int8u video_parameter_set_id_, int8u chroma_format_idc_, bool separate_colour_plane_flag_, int8u log2_max_pic_order_cnt_lsb_minus4_, int8u bit_depth_luma_minus8_, int8u bit_depth_chroma_minus8_, bool general_progressive_source_flag_, bool general_interlaced_source_flag_, bool general_frame_only_constraint_flag_)
+        seq_parameter_set_struct(vui_parameters_struct* vui_parameters_, int32u profile_space_, bool tier_flag_, int32u profile_idc_, int32u level_idc_, int32u pic_width_in_luma_samples_, int32u pic_height_in_luma_samples_, int32u conf_win_left_offset_, int32u conf_win_right_offset_, int32u conf_win_top_offset_, int32u conf_win_bottom_offset_, int8u video_parameter_set_id_, int8u chroma_format_idc_, bool separate_colour_plane_flag_, int8u log2_max_pic_order_cnt_lsb_minus4_, int8u bit_depth_luma_minus8_, int8u bit_depth_chroma_minus8_, bool general_progressive_source_flag_, bool general_interlaced_source_flag_, bool general_frame_only_constraint_flag_, bool general_max_8bit_constraint_flag_)
             :
             vui_parameters(vui_parameters_),
             #if MEDIAINFO_DEMUX
@@ -252,7 +253,8 @@ private :
             bit_depth_chroma_minus8(bit_depth_chroma_minus8_),
             general_progressive_source_flag(general_progressive_source_flag_),
             general_interlaced_source_flag(general_interlaced_source_flag_),
-            general_frame_only_constraint_flag(general_frame_only_constraint_flag_)
+            general_frame_only_constraint_flag(general_frame_only_constraint_flag_),
+            general_max_8bit_constraint_flag(general_max_8bit_constraint_flag_)
         {
         }
 
@@ -343,7 +345,6 @@ private :
 
     //Elements
     void slice_segment_layer();
-    void slice_layer();
     void video_parameter_set();
     void seq_parameter_set();
     void pic_parameter_set();
@@ -357,6 +358,13 @@ private :
     void sei_message_buffering_period_xxl(seq_parameter_set_struct::vui_parameters_struct::xxl_common* xxL_Common, bool irap_cpb_params_present_flag, seq_parameter_set_struct::vui_parameters_struct::xxl* xxl);
     void sei_message_pic_timing(int32u &seq_parameter_set_id, int32u payloadSize);
     void sei_message_user_data_registered_itu_t_t35();
+    void sei_message_user_data_registered_itu_t_t35_B5();
+    void sei_message_user_data_registered_itu_t_t35_B5_003A();
+    void sei_message_user_data_registered_itu_t_t35_B5_003A_00();
+    void sei_message_user_data_registered_itu_t_t35_B5_003A_02();
+    void sei_message_user_data_registered_itu_t_t35_B5_003C();
+    void sei_message_user_data_registered_itu_t_t35_B5_003C_0001();
+    void sei_message_user_data_registered_itu_t_t35_B5_003C_0001_04();
     void sei_message_user_data_unregistered(int32u payloadSize);
     void sei_message_user_data_unregistered_Ateme(int32u payloadSize);
     void sei_message_user_data_unregistered_x265(int32u payloadSize);
@@ -380,18 +388,7 @@ private :
     void VPS_SPS_PPS();
     void VPS_SPS_PPS_FromMatroska();
 
-    //Streams
-    struct stream
-    {
-        bool   Searching_Payload;
-
-        stream()
-            :
-            Searching_Payload(false)
-        {
-        }
-    };
-    vector<stream> Streams;
+    vector<stream_payload> Streams;
 
     //Replacement of File__Analyze buffer
     const int8u*                        Buffer_ToSave;
@@ -416,8 +413,14 @@ private :
     Ztring                              Encoded_Library_Version;
     Ztring                              Encoded_Library_Date;
     Ztring                              Encoded_Library_Settings;
-    Ztring                              MasteringDisplay_ColorPrimaries;
-    Ztring                              MasteringDisplay_Luminance;
+    enum hdr_format
+    {
+        HdrFormat_EtsiTs103433,
+        HdrFormat_SmpteSt209440,
+        HdrFormat_SmpteSt2086,
+    };
+    typedef std::map<hdr_format, std::map<video, Ztring> > hdr;
+    hdr                                 HDR;
     Ztring                              EtsiTS103433;
     int32u  chroma_format_idc;
     int32u  slice_pic_parameter_set_id;
@@ -435,6 +438,7 @@ private :
     bool    general_progressive_source_flag;
     bool    general_interlaced_source_flag;
     bool    general_frame_only_constraint_flag;
+    bool    general_max_8bit_constraint_flag;
     bool    RapPicFlag;
     bool    first_slice_segment_in_pic_flag;
 };
