@@ -1,11 +1,11 @@
 //---------------------------------------------------------------------------
-#include <wx/wxprec.h>
+//#include <wx/wxprec.h>
 #ifdef __BORLANDC__
     #pragma hdrstop
 #endif
 //---------------------------------------------------------------------------
 //---------------------------------------------------------------------------
-#include <wx/file.h>
+//#include <wx/file.h>
 #include <ZenLib/File.h>
 #include <ZenLib/ZtringListListF.h>
 #include "PreRelease/Resources.h"
@@ -18,8 +18,8 @@ using namespace std;
 // Open a file
 ZenLib::Ztring Resources_Create_Load(Ztring FileName, Ztring &Contents)
 {
-    wxFile F;
-    if (F.Open(FileName.c_str(), wxFile::read)==false)
+    File F;
+    if (F.Open(FileName.c_str())==false)
     {
         Ztring ToReturn=L"Problems to open ";
         ToReturn+=FileName;
@@ -179,6 +179,11 @@ ZenLib::Ztring Resources_Create()
         return Result;
     Out+=Contents;
 
+    Result=Resources_Create_Item(L"DataBase", L"CodecID_Other_Mpeg4", L"InfoMap", Contents);
+    if (!Result.empty())
+        return Result;
+    Out+=Contents;
+
     Result=Resources_Create_Item(L"DataBase", L"Codec", L"InfoMap", Contents);
     if (!Result.empty())
         return Result;
